ScriptName _sycMainQuestScript extends Quest Conditional

Import Game
Import Actor
Import ActorBase
Import ObjectReference
Import Utility
Import Sound
Import Debug


;---------------------------------------------------------------------------------------------------
;### DECLARED VARIABLES/PROPERTIES ###
;---------------------------------------------------------------------------------------------------

;## Hidden Properties ##
; Version
Float fLatestVersion
Float Property fVersion Auto	; Must keep as a property or value will be lost if redeclared as a local variable.
; Hidden Properties
Bool bShowEnableCCOPrompt
Bool bCCODisabledOnCharacter
Bool bPlayOpenCCOMenuSound
Bool bToggleModuleNotificationsOn
; Module States
Bool bDiverseRaceAndGendersApplied
Bool bDynamicSkillProgressionApplied
Bool bOblivionCarryWeightsApplied
Bool bPermanentBirthsignsApplied

;## Menu Choices ##
Int iBirthsign
Int iSpecialization
Int iAttribute
Int Property iMajorSkill1 Auto Conditional	; Must first use integers than assign to an array, otherwise we cannot conditionalize the Menu options
Int Property iMajorSkill2 Auto Conditional
Int Property iMajorSkill3 Auto Conditional
Int Property iMajorSkill4 Auto Conditional
Int Property iMajorSkill5 Auto Conditional
Int Property iMajorSkill6 Auto Conditional

;## Sound FX ##
Sound Property _sycSFXOpenMenu Auto	; Open Main Menu Sound
Sound Property MAGMysticismSoulTrapCapture Auto	; Close Main Menu Sound

;## Attributes ##
Float fHealthModifier
Float fMagickaModifier
Float fStaminaModifier
Float fCarryWeightModifier
; For Display in Race Menu
Float fHealth
Float fMagicka
Float fStamina
Float fCarryWeight

;## Skills ##
Float fAlchemySkillModifier
Float fAlterationSkillModifier
Float fBlockSkillModifier
Float fConjurationSkillModifier
Float fDestructionSkillModifier
Float fEnchantingSkillModifier
Float fHeavyArmorSkillModifier
Float fIllusionSkillModifier
Float fLightArmorSkillModifier
Float fLockpickingSkillModifier
Float fMarksmanSkillModifier
Float fOneHandedSkillModifier
Float fPickpocketSkillModifier
Float fRestorationSkillModifier
Float fSmithingSkillModifier
Float fSneakSkillModifier
Float fSpeechcraftSkillModifier
Float fTwoHandedSkillModifier

;## Skill Rates ##
Float fAlchemySkillRate
Float fAlterationSkillRate
Float fBlockSkillRate
Float fConjurationSkillRate
Float fDestructionSkillRate
Float fEnchantingSkillRate
Float fHeavyArmorSkillRate
Float fIllusionSkillRate
Float fLightArmorSkillRate
Float fLockpickingSkillRate
Float fMarksmanSkillRate
Float fOneHandedSkillRate
Float fPickpocketSkillRate
Float fRestorationSkillRate
Float fSmithingSkillRate
Float fSneakSkillRate
Float fSpeechcraftSkillRate
Float fTwoHandedSkillRate

;## References ##
Quest Property MQ101 Auto
Actor Property PlayerREF Auto
; Races
Race Property HighElfRace Auto
Race Property ArgonianRace Auto
Race Property WoodElfRace Auto
Race Property BretonRace Auto
Race Property DarkElfRace Auto
Race Property ImperialRace Auto
Race Property KhajiitRace Auto
Race Property NordRace Auto
Race Property OrcRace Auto
Race Property RedguardRace Auto
Race Property HighElfRaceVampire Auto
Race Property ArgonianRaceVampire Auto
Race Property WoodElfRaceVampire Auto
Race Property BretonRaceVampire Auto
Race Property DarkElfRaceVampire Auto
Race Property ImperialRaceVampire Auto
Race Property KhajiitRaceVampire Auto
Race Property NordRaceVampire Auto
Race Property OrcRaceVampire Auto
Race Property RedguardRaceVampire Auto
; Books
Book Property _sycCCOBook Auto

;## Carry Weight Spells ##
Spell Property _sycDecreasedCarryWeight50Ability Auto
Spell Property _sycIncreasedCarryWeight30Ability Auto
Spell Property _sycIncreasedCarryWeight50Ability Auto

;## Birthsign Abilities and Perks ##
Spell Property DoomApprenticeAbility Auto
Spell Property DoomApprenticeNegativeAbility Auto
Spell Property DoomAtronachAbility Auto		
Spell Property DoomLadyAbility Auto	
Spell Property DoomLordAbility Auto	
Spell Property DoomLoverAbility Auto
Spell Property DoomMageAbility Auto	
Spell Property DoomRitualAbility Auto
Perk Property DoomRitualPerk Auto
Spell Property DoomSerpentAbility Auto	
Spell Property DoomShadowAbility Auto	
Spell Property DoomSteedAbility Auto	
Spell Property DoomThiefAbility Auto	
Spell Property DoomTowerAbility Auto	
Spell Property DoomWarriorAbility Auto
; The Lover Birthsign removes these spells
Spell Property Rested Auto
Spell Property WellRested Auto
Spell Property MarriageRested Auto
	
;## Skill Rate Perks ##
; +5%
Perk Property _sycSkillRateAlchemy105Perk Auto
Perk Property _sycSkillRateAlteration105Perk Auto
Perk Property _sycSkillRateBlock105Perk Auto
Perk Property _sycSkillRateConjuration105Perk Auto
Perk Property _sycSkillRateDestruction105Perk Auto
Perk Property _sycSkillRateEnchanting105Perk Auto
Perk Property _sycSkillRateHeavyArmor105Perk Auto
Perk Property _sycSkillRateIllusion105Perk Auto
Perk Property _sycSkillRateLightArmor105Perk Auto
Perk Property _sycSkillRateLockpicking105Perk Auto
Perk Property _sycSkillRateMarksman105Perk Auto
Perk Property _sycSkillRateOneHanded105Perk Auto
Perk Property _sycSkillRatePickpocket105Perk Auto
Perk Property _sycSkillRateRestoration105Perk Auto
Perk Property _sycSkillRateSmithing105Perk Auto
Perk Property _sycSkillRateSneak105Perk Auto
Perk Property _sycSkillRateSpeechcraft105Perk Auto
Perk Property _sycSkillRateTwoHanded105Perk Auto
; +10%
Perk Property _sycSkillRateAlchemy110Perk Auto
Perk Property _sycSkillRateAlteration110Perk Auto
Perk Property _sycSkillRateBlock110Perk Auto
Perk Property _sycSkillRateConjuration110Perk Auto
Perk Property _sycSkillRateDestruction110Perk Auto
Perk Property _sycSkillRateEnchanting110Perk Auto
Perk Property _sycSkillRateHeavyArmor110Perk Auto
Perk Property _sycSkillRateIllusion110Perk Auto
Perk Property _sycSkillRateLightArmor110Perk Auto
Perk Property _sycSkillRateLockpicking110Perk Auto
Perk Property _sycSkillRateMarksman110Perk Auto
Perk Property _sycSkillRateOneHanded110Perk Auto
Perk Property _sycSkillRatePickpocket110Perk Auto
Perk Property _sycSkillRateRestoration110Perk Auto
Perk Property _sycSkillRateSmithing110Perk Auto
Perk Property _sycSkillRateSneak110Perk Auto
Perk Property _sycSkillRateSpeechcraft110Perk Auto
Perk Property _sycSkillRateTwoHanded110Perk Auto
; +15%
Perk Property _sycSkillRateAlchemy115Perk Auto
Perk Property _sycSkillRateAlteration115Perk Auto
Perk Property _sycSkillRateBlock115Perk Auto
Perk Property _sycSkillRateConjuration115Perk Auto
Perk Property _sycSkillRateDestruction115Perk Auto
Perk Property _sycSkillRateEnchanting115Perk Auto
Perk Property _sycSkillRateHeavyArmor115Perk Auto
Perk Property _sycSkillRateIllusion115Perk Auto
Perk Property _sycSkillRateLightArmor115Perk Auto
Perk Property _sycSkillRateLockpicking115Perk Auto
Perk Property _sycSkillRateMarksman115Perk Auto
Perk Property _sycSkillRateOneHanded115Perk Auto
Perk Property _sycSkillRatePickpocket115Perk Auto
Perk Property _sycSkillRateRestoration115Perk Auto
Perk Property _sycSkillRateSmithing115Perk Auto
Perk Property _sycSkillRateSneak115Perk Auto
Perk Property _sycSkillRateSpeechcraft115Perk Auto
Perk Property _sycSkillRateTwoHanded115Perk Auto
; +20%
Perk Property _sycSkillRateAlchemy120Perk Auto
Perk Property _sycSkillRateAlteration120Perk Auto
Perk Property _sycSkillRateBlock120Perk Auto
Perk Property _sycSkillRateConjuration120Perk Auto
Perk Property _sycSkillRateDestruction120Perk Auto
Perk Property _sycSkillRateEnchanting120Perk Auto
Perk Property _sycSkillRateHeavyArmor120Perk Auto
Perk Property _sycSkillRateIllusion120Perk Auto
Perk Property _sycSkillRateLightArmor120Perk Auto
Perk Property _sycSkillRateLockpicking120Perk Auto
Perk Property _sycSkillRateMarksman120Perk Auto
Perk Property _sycSkillRateOneHanded120Perk Auto
Perk Property _sycSkillRatePickpocket120Perk Auto
Perk Property _sycSkillRateRestoration120Perk Auto
Perk Property _sycSkillRateSmithing120Perk Auto
Perk Property _sycSkillRateSneak120Perk Auto
Perk Property _sycSkillRateSpeechcraft120Perk Auto
Perk Property _sycSkillRateTwoHanded120Perk Auto
; +25%
Perk Property _sycSkillRateAlchemy125Perk Auto
Perk Property _sycSkillRateAlteration125Perk Auto
Perk Property _sycSkillRateBlock125Perk Auto
Perk Property _sycSkillRateConjuration125Perk Auto
Perk Property _sycSkillRateDestruction125Perk Auto
Perk Property _sycSkillRateEnchanting125Perk Auto
Perk Property _sycSkillRateHeavyArmor125Perk Auto
Perk Property _sycSkillRateIllusion125Perk Auto
Perk Property _sycSkillRateLightArmor125Perk Auto
Perk Property _sycSkillRateLockpicking125Perk Auto
Perk Property _sycSkillRateMarksman125Perk Auto
Perk Property _sycSkillRateOneHanded125Perk Auto
Perk Property _sycSkillRatePickpocket125Perk Auto
Perk Property _sycSkillRateRestoration125Perk Auto
Perk Property _sycSkillRateSmithing125Perk Auto
Perk Property _sycSkillRateSneak125Perk Auto
Perk Property _sycSkillRateSpeechcraft125Perk Auto
Perk Property _sycSkillRateTwoHanded125Perk Auto
; +30%
Perk Property _sycSkillRateAlchemy130Perk Auto
Perk Property _sycSkillRateAlteration130Perk Auto
Perk Property _sycSkillRateBlock130Perk Auto
Perk Property _sycSkillRateConjuration130Perk Auto
Perk Property _sycSkillRateDestruction130Perk Auto
Perk Property _sycSkillRateEnchanting130Perk Auto
Perk Property _sycSkillRateHeavyArmor130Perk Auto
Perk Property _sycSkillRateIllusion130Perk Auto
Perk Property _sycSkillRateLightArmor130Perk Auto
Perk Property _sycSkillRateLockpicking130Perk Auto
Perk Property _sycSkillRateMarksman130Perk Auto
Perk Property _sycSkillRateOneHanded130Perk Auto
Perk Property _sycSkillRatePickpocket130Perk Auto
Perk Property _sycSkillRateRestoration130Perk Auto
Perk Property _sycSkillRateSmithing130Perk Auto
Perk Property _sycSkillRateSneak130Perk Auto
Perk Property _sycSkillRateSpeechcraft130Perk Auto
Perk Property _sycSkillRateTwoHanded130Perk Auto
; +35%
Perk Property _sycSkillRateAlchemy135Perk Auto
Perk Property _sycSkillRateAlteration135Perk Auto
Perk Property _sycSkillRateBlock135Perk Auto
Perk Property _sycSkillRateConjuration135Perk Auto
Perk Property _sycSkillRateDestruction135Perk Auto
Perk Property _sycSkillRateEnchanting135Perk Auto
Perk Property _sycSkillRateHeavyArmor135Perk Auto
Perk Property _sycSkillRateIllusion135Perk Auto
Perk Property _sycSkillRateLightArmor135Perk Auto
Perk Property _sycSkillRateLockpicking135Perk Auto
Perk Property _sycSkillRateMarksman135Perk Auto
Perk Property _sycSkillRateOneHanded135Perk Auto
Perk Property _sycSkillRatePickpocket135Perk Auto
Perk Property _sycSkillRateRestoration135Perk Auto
Perk Property _sycSkillRateSmithing135Perk Auto
Perk Property _sycSkillRateSneak135Perk Auto
Perk Property _sycSkillRateSpeechcraft135Perk Auto
Perk Property _sycSkillRateTwoHanded135Perk Auto

;## Messages ##
; Enable CCO Message
Message Property _sycEnableCCOPromptMSG Auto
; Uninstall Messages
Message Property _sycCCOUninstallerActivatedByAccidentMSG Auto
Message Property _sycConfirmUninstallCCOMSG Auto
Message Property _sycCCOUninstallationCanceledMSG Auto
Message Property _sycCCOUninstallationCompleteMSG Auto
; Upgrade Messages
Message Property _sycUpgradeCCOMSG Auto
Message Property _sycUpgradeCCOOptionsMSG Auto
; CCO Book
Message Property _sycWriteBookPromptMSG Auto
Message Property _sycRewriteBookPromptMSG Auto
Message Property _sycWriteInCCOBookPromptMSG Auto
Message Property _sycReviseCCOBookPromptMSG Auto
; Birthsigns
Message Property _sycBirthsignApprenticeMSG Auto
Message Property _sycBirthsignAtronachMSG Auto		
Message Property _sycBirthsignLadyMSG Auto	
Message Property _sycBirthsignLordMSG Auto	
Message Property _sycBirthsignLoverMSG Auto
Message Property _sycBirthsignMageMSG Auto	
Message Property _sycBirthsignRitualMSG Auto	
Message Property _sycBirthsignSerpentMSG Auto	
Message Property _sycBirthsignShadowMSG Auto	
Message Property _sycBirthsignSteedMSG Auto	
Message Property _sycBirthsignThiefMSG Auto	
Message Property _sycBirthsignTowerMSG Auto	
Message Property _sycBirthsignWarriorMSG Auto
Message Property _sycBirthsignNoneMSG Auto
; Races Male
Message Property _sycRaceHighElfMaleMSG Auto
Message Property _sycRaceArgonianMaleMSG Auto
Message Property _sycRaceWoodElfMaleMSG Auto
Message Property _sycRaceBretonMaleMSG Auto
Message Property _sycRaceDarkElfMaleMSG Auto
Message Property _sycRaceImperialMaleMSG Auto
Message Property _sycRaceKhajiitMaleMSG Auto
Message Property _sycRaceNordMaleMSG Auto
Message Property _sycRaceOrcMaleMSG Auto
Message Property _sycRaceRedguardMaleMSG Auto
; Races Female
Message Property _sycRaceHighElfFemaleMSG Auto
Message Property _sycRaceArgonianFemaleMSG Auto
Message Property _sycRaceWoodElfFemaleMSG Auto
Message Property _sycRaceBretonFemaleMSG Auto
Message Property _sycRaceDarkElfFemaleMSG Auto
Message Property _sycRaceImperialFemaleMSG Auto
Message Property _sycRaceKhajiitFemaleMSG Auto
Message Property _sycRaceNordFemaleMSG Auto
Message Property _sycRaceOrcFemaleMSG Auto
Message Property _sycRaceRedguardFemaleMSG Auto
; Choose Birthsign
Message Property _sycChooseBirthsign1MSG Auto
Message Property _sycChooseBirthsign2MSG Auto
Message Property _sycChooseBirthsign3MSG Auto
; Choose Class
Message Property _sycChooseClassMSG Auto
Message Property _sycCombatClassesMSG Auto
Message Property _sycMagicClassesMSG Auto
Message Property _sycStealthClassesMSG Auto
; Classes
Message Property _sycClassArcherMSG Auto
Message Property _sycClassBarbarianMSG Auto
Message Property _sycClassCrusaderMSG Auto
Message Property _sycClassKnightMSG Auto
Message Property _sycClassRogueMSG Auto
Message Property _sycClassScoutMSG Auto
Message Property _sycClassWarriorMSG Auto
Message Property _sycClassBattlemageMSG Auto
Message Property _sycClassHealerMSG Auto
Message Property _sycClassMageMSG Auto
Message Property _sycClassNightbladeMSG Auto
Message Property _sycClassSorcererMSG Auto
Message Property _sycClassSpellswordMSG Auto
Message Property _sycClassWitchhunterMSG Auto
Message Property _sycClassAcrobatMSG Auto
Message Property _sycClassAgentMSG Auto
Message Property _sycClassAssassinMSG Auto
Message Property _sycClassBardMSG Auto
Message Property _sycClassMonkMSG Auto
Message Property _sycClassPilgrimMSG Auto
Message Property _sycClassThiefMSG Auto
; Choose Specialization
Message Property _sycChooseSpecializationMSG Auto
Message Property _sycCombatSpecializationMSG Auto
Message Property _sycMagicSpecializationMSG Auto
Message Property _sycStealthSpecializationMSG Auto
; Choose Attribute
Message Property _sycChooseAttributeMSG Auto
; Choose Major Skills
Message Property _sycChooseMajorSkill1MSG Auto
Message Property _sycChooseMajorSkill2MSG Auto
Message Property _sycChooseMajorSkill3MSG Auto
Message Property _sycChooseMajorSkill4MSG Auto
Message Property _sycChooseMajorSkill5MSG Auto
Message Property _sycChooseMajorSkill6MSG Auto
; Skill Types
Message Property _sycCombatSkillsMSG Auto
Message Property _sycMagicSkillsMSG Auto
Message Property _sycStealthSkillsMSG Auto
; Combat Skills
Message Property _sycSkillArcheryMSG Auto
Message Property _sycSkillBlockMSG Auto
Message Property _sycSkillHeavyArmorMSG Auto
Message Property _sycSkillOneHandedMSG Auto
Message Property _sycSkillSmithingMSG Auto
Message Property _sycSkillTwoHandedMSG Auto
; Magic Skills
Message Property _sycSkillAlterationMSG Auto	
Message Property _sycSkillConjurationMSG Auto
Message Property _sycSkillDestructionMSG Auto
Message Property _sycSkillEnchantingMSG Auto
Message Property _sycSkillIllusionMSG Auto
Message Property _sycSkillRestorationMSG Auto
; Stealth Skills
Message Property _sycSkillAlchemyMSG Auto
Message Property _sycSkillLightArmorMSG Auto
Message Property _sycSkillLockpickingMSG Auto
Message Property _sycSkillPickpocketMSG Auto
Message Property _sycSkillSneakMSG Auto
Message Property _sycSkillSpeechMSG Auto

;## Diverse Races And Genders ##
; Races Male
Message Property _sycRaceHighElfMaleDSPMSG Auto
Message Property _sycRaceArgonianMaleDSPMSG Auto
Message Property _sycRaceWoodElfMaleDSPMSG Auto
Message Property _sycRaceBretonMaleDSPMSG Auto
Message Property _sycRaceDarkElfMaleDSPMSG Auto
Message Property _sycRaceImperialMaleDSPMSG Auto
Message Property _sycRaceKhajiitMaleDSPMSG Auto
Message Property _sycRaceNordMaleDSPMSG Auto
Message Property _sycRaceOrcMaleDSPMSG Auto
Message Property _sycRaceRedguardMaleDSPMSG Auto
; Races Female
Message Property _sycRaceHighElfFemaleDSPMSG Auto
Message Property _sycRaceArgonianFemaleDSPMSG Auto
Message Property _sycRaceWoodElfFemaleDSPMSG Auto
Message Property _sycRaceBretonFemaleDSPMSG Auto
Message Property _sycRaceDarkElfFemaleDSPMSG Auto
Message Property _sycRaceImperialFemaleDSPMSG Auto
Message Property _sycRaceKhajiitFemaleDSPMSG Auto
Message Property _sycRaceNordFemaleDSPMSG Auto
Message Property _sycRaceOrcFemaleDSPMSG Auto
Message Property _sycRaceRedguardFemaleDSPMSG Auto
; Custom Race
Message Property _sycRaceCustomMSG Auto
; Choose Specialization
Message Property _sycChooseSpecializationDSPMSG Auto
Message Property _sycCombatSpecializationDSPMSG Auto
Message Property _sycMagicSpecializationDSPMSG Auto
Message Property _sycStealthSpecializationDSPMSG Auto
; Choose Major Skills
Message Property _sycChooseMajorSkill1DSPMSG Auto
Message Property _sycChooseMajorSkill2DSPMSG Auto
Message Property _sycChooseMajorSkill3DSPMSG Auto
Message Property _sycChooseMajorSkill4DSPMSG Auto
Message Property _sycChooseMajorSkill5DSPMSG Auto
Message Property _sycChooseMajorSkill6DSPMSG Auto

;## Oblivion Carry Weights ##
Spell Property _sycDecreasedCarryWeight100Ability Auto

;## Deprecated ##
Bool Property bUsingCustomRace Auto Conditional
Message Property _sycDynamicDynamicSkillProgressionMSG Auto
Perk Property _sycSkillRateAlchemy090Perk Auto
Perk Property _sycSkillRateAlteration090Perk Auto
Perk Property _sycSkillRateBlock090Perk Auto
Perk Property _sycSkillRateConjuration090Perk Auto
Perk Property _sycSkillRateDestruction090Perk Auto
Perk Property _sycSkillRateEnchanting090Perk Auto
Perk Property _sycSkillRateHeavyArmor090Perk Auto
Perk Property _sycSkillRateIllusion090Perk Auto
Perk Property _sycSkillRateLightArmor090Perk Auto
Perk Property _sycSkillRateLockpicking090Perk Auto
Perk Property _sycSkillRateMarksman090Perk Auto
Perk Property _sycSkillRateOneHanded090Perk Auto
Perk Property _sycSkillRatePickpocket090Perk Auto
Perk Property _sycSkillRateRestoration090Perk Auto
Perk Property _sycSkillRateSmithing090Perk Auto
Perk Property _sycSkillRateSneak090Perk Auto
Perk Property _sycSkillRateSpeechcraft090Perk Auto
Perk Property _sycSkillRateTwoHanded090Perk Auto


;---------------------------------------------------------------------------------------------------
;### MAIN SCRIPT ###
;---------------------------------------------------------------------------------------------------

; Event OnInit()
	; This script is now started via _sycMaintenanceRefAliasScript calling the VersionControl()
; EndEvent


State WaitForShowRaceMenu
	;## Wait For ShowRaceMenu to Finish ##
	Event OnUpdate()
		If IsJournalControlsEnabled() && IsActivateControlsEnabled() && IsFightingControlsEnabled() && !IsInMenuMode()	; In case using Alternate Start mods, check if player done picking race
			UnregisterForUpdate()
			GoToState("ResetVars")
		ElseIf MQ101.GetStageDone(75) && !IsInMenuMode()	; Check if player done picking race (Vanilla Only)
			UnregisterForUpdate()
			GoToState("ResetVars")
		EndIf
	EndEvent
EndState

State ResetVars
	Event OnBeginState()
		If bShowEnableCCOPrompt == True
			bShowEnableCCOPrompt = False
			EnableCCOPrompt()
			Return	; Return if CCO is disabled so no other code runs
		EndIf
		If bPlayOpenCCOMenuSound == True
			bPlayOpenCCOMenuSound = False
			_sycSFXOpenMenu.Play(PlayerREF)	; Play sound when Menu activates
			WaitMenuMode(1.95)	; Sync Menu with Sound Effect
		EndIf
		ResetBaseStats()
		ResetMenuChoices()
		GoToState("InitializeCCOMenu")
	EndEvent
EndState

State InitializeCCOMenu
	Event OnBeginState()
		AssignRaceMenuDisplayStats()
		ChooseRaceMenu()
	EndEvent
EndState

State AssignClassStats
	Event OnBeginState()
		CloseCCOBook()	; Close book in case CCO Menu is activated from the book
		MAGMysticismSoulTrapCapture.Play(PlayerREF)	; Play sound to indicate completion		
		AssignSpecialization()
		AssignFavoredAttribute()
		AssignMajorSkills()
		GoToState("ApplyAllStats")
	EndEvent
EndState

State ApplyAllStats
	Event OnBeginState()
		ApplyBirthsign()
		ApplySkillValues()
		ToggleModules()
		If bDiverseRaceAndGendersApplied == False
			ApplyAttributes()
		EndIf
		If PlayerREF.GetItemCount(_sycCCOBook) == 0
			PlayerREF.AddItem(_sycCCOBook, 1, False)
		EndIf
		GoToState("StopQuest")
	EndEvent
EndState

State StopQuest
	Event OnBeginState()
		Stop()
	EndEvent
EndState

;---------------------------------------------------------------------------------------------------
;### FUNCTIONS ###
;---------------------------------------------------------------------------------------------------

;### Enable CCO Prompt Function ###
;---------------------------------------------------------------------------------------------------
; Shows the menu asking whether to enable CCO on current character
Function EnableCCOPrompt(Int aiButtonChoice1 = -1)		
	aiButtonChoice1 = _sycEnableCCOPromptMSG.Show()
	If aiButtonChoice1 == 0	; Yes
		bPlayOpenCCOMenuSound = True
		GoToState("ResetVars")
	ElseIf aiButtonChoice1 == 1	; No
		bCCODisabledOnCharacter = True
		If PlayerREF.GetItemCount(_sycCCOBook) == 0
			PlayerREF.AddItem(_sycCCOBook)
		EndIf
		GoToState("StopQuest")
	EndIf
EndFunction


;### Open CCO Book Function ###
;---------------------------------------------------------------------------------------------------
; Triggered from the script attached to _sycCCOBook ("A New Beginning")
Function OpenCCOBook(Int aiButtonChoice1 = -1)
	If bCCODisabledOnCharacter == True
		aiButtonChoice1 = _sycWriteInCCOBookPromptMSG.Show()
		If aiButtonChoice1 == 0	; Write In
			bCCODisabledOnCharacter = False
			Notification("Writing...")
			CloseCCOBook()	; Close book, otherwise if you ShowRaceMenu the ChooseRaceMenu will not appear until book is closed
			bPlayOpenCCOMenuSound = True
			GoToState("ResetVars")	; Go straight to Race Menu
		ElseIf aiButtonChoice1 == 1	; Leave Blank
			CloseCCOBook()
			Return
		EndIf
	Else
		aiButtonChoice1 = _sycReviseCCOBookPromptMSG.Show()
		If aiButtonChoice1 == 0	; Revise
			Notification("Revising...")
			UninstallCCOCurrentVersion()	; Attributes and Skills need to be reset first
			CloseCCOBook()
			bShowEnableCCOPrompt = True
			bPlayOpenCCOMenuSound = True
			GoToState("ResetVars")	; Go straight to Race Menu
		ElseIf aiButtonChoice1 == 1	; Destroy
			CloseCCOBook()
			UninstallCCO()
		ElseIf aiButtonChoice1 == 2	; Close
			CloseCCOBook()
		EndIf
	EndIf
EndFunction


;### Open CCO Book Function ###
;---------------------------------------------------------------------------------------------------
;http://forums.bethsoft.com/topic/1373468-quick-questions-quick-answers-thread-4/page__view__findpost__p__21152768
Function CloseCCOBook()
	Game.DisablePlayerControls(False, False, False, False, False, True) ; Momentarily disable other menus
	PlayerREF.EquipItem(_sycCCOBook, True, True) ; Prevent unequip/reequip in favorites until the current menu is resolved
	Wait(0.01) ; This ensures equipping the token from the favorites menu works
	PlayerREF.UnequipItem(_sycCCOBook, False, True) ; Silently unequip item
	Game.EnablePlayerControls(False, False, False, False, False, True) ; Undo DisablePlayerControls
EndFunction


;### Reset Hidden Properties ###
;---------------------------------------------------------------------------------------------------
; Sets/resets hidden properties for uninstallation only.
Function ResetHiddenProperties()
	fVersion = 0
	bCCODisabledOnCharacter = False
	bShowEnableCCOPrompt = False
	bPlayOpenCCOMenuSound = False
	bToggleModuleNotificationsOn = False
EndFunction


;### Reset Menu Choices Function ###
;---------------------------------------------------------------------------------------------------
; Sets/resets the CCO menu choices
Function ResetMenuChoices()
	;## Clear Menu Choices ##
	iBirthsign = -1
	iSpecialization = -1
	iAttribute = -1
	iMajorSkill1 = -1
	iMajorSkill2 = -1
	iMajorSkill3 = -1
	iMajorSkill4 = -1
	iMajorSkill5 = -1
	iMajorSkill6 = -1
EndFunction


;### Reset Base Stats (Mofidiers) Function ###
;---------------------------------------------------------------------------------------------------
; Sets/resets the base stats before they are modified
Function ResetBaseStats()
	ResetAttributeAndCarryWeightModifiers()
	ResetSkillValueModifiers()
	ResetSkillRates()
EndFunction


;### Reset Attribute Modifiers Function ###
;---------------------------------------------------------------------------------------------------
Function ResetAttributeAndCarryWeightModifiers()
	fHealthModifier = 0
	fMagickaModifier = 0
	fStaminaModifier = 0
	fCarryWeightModifier = 0
EndFunction


;### Reset Skill Value Modifiers ###
;---------------------------------------------------------------------------------------------------
Function ResetSkillValueModifiers()
	fAlchemySkillModifier = 0
	fAlterationSkillModifier = 0
	fBlockSkillModifier = 0
	fConjurationSkillModifier = 0
	fDestructionSkillModifier = 0
	fEnchantingSkillModifier = 0
	fHeavyArmorSkillModifier = 0
	fIllusionSkillModifier = 0
	fLightArmorSkillModifier = 0
	fLockpickingSkillModifier = 0
	fMarksmanSkillModifier = 0
	fOneHandedSkillModifier = 0
	fPickpocketSkillModifier = 0
	fRestorationSkillModifier = 0
	fSmithingSkillModifier = 0
	fSneakSkillModifier = 0
	fSpeechcraftSkillModifier = 0
	fTwoHandedSkillModifier = 0	
EndFunction


;### Reset Skill Rate Modifiers ###
;---------------------------------------------------------------------------------------------------
Function ResetSkillRates()
	; Set all skill rates to 100%
	fAlchemySkillRate = 1.00
	fAlterationSkillRate = 1.00
	fBlockSkillRate = 1.00
	fConjurationSkillRate = 1.00
	fDestructionSkillRate = 1.00
	fEnchantingSkillRate = 1.00
	fHeavyArmorSkillRate = 1.00
	fIllusionSkillRate = 1.00
	fLightArmorSkillRate = 1.00
	fLockpickingSkillRate = 1.00
	fMarksmanSkillRate = 1.00
	fOneHandedSkillRate = 1.00
	fPickpocketSkillRate = 1.00
	fRestorationSkillRate = 1.00
	fSmithingSkillRate = 1.00
	fSneakSkillRate = 1.00
	fSpeechcraftSkillRate = 1.00
	fTwoHandedSkillRate = 1.00
EndFunction


;### Assign Race Display Stats ###
;---------------------------------------------------------------------------------------------------
; This function assigns the stats to show in the Choose Race Menu
Function AssignRaceMenuDisplayStats()
	If Game.GetFormFromFile(0x00000D62, "CCO - Diverse Races And Genders.esp")
		AssignDiverseRacesAndGendersAttributes()
	EndIf
	fHealth = PlayerREF.GetBaseAV("Health") + fHealthModifier	; Set fHealth for displaying in Race Menu
	fMagicka = PlayerREF.GetBaseAV("Magicka") + fMagickaModifier	; Set fMagicka for displaying in Race Menu
	fStamina = PlayerREF.GetBaseAV("Stamina") + fStaminaModifier	; Set fStamina for displaying in Race Menu
	fCarryWeight = PlayerREF.GetBaseAV("CarryWeight") + fCarryWeightModifier	; Set fCarryWeight for displaying in Race Menu
	If Game.GetFormFromFile(0x00000D62, "CCO - Oblivion Carry Weights.esp")
		fCarryWeight += -100
	EndIf
EndFunction


;### Choose Race Menu Function ###
;---------------------------------------------------------------------------------------------------
; This function shows the Choose Race Menu
Function ChooseRaceMenu(Int aiButtonChoice1 = -1)
	;## Show Specific Race Message ##
	ActorBase PlayerREFBase = PlayerREF.GetBaseObject() as ActorBase
	;## Standard Races ##
	If PlayerREF.GetRace() == ArgonianRace || PlayerREF.GetRace() == ArgonianRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceArgonianMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceArgonianMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceArgonianFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceArgonianFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == BretonRace || PlayerREF.GetRace() == BretonRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceBretonMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceBretonMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceBretonFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceBretonFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == DarkElfRace || PlayerREF.GetRace() == DarkElfRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceDarkElfMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceDarkElfMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceDarkElfFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceDarkElfFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == HighElfRace || PlayerREF.GetRace() == HighElfRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceHighElfMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceHighElfMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceHighElfFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceHighElfFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == ImperialRace || PlayerREF.GetRace() == ImperialRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceImperialMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceImperialMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceImperialFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceImperialFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == KhajiitRace || PlayerREF.GetRace() == KhajiitRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceKhajiitMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceKhajiitMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceKhajiitFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceKhajiitFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == NordRace || PlayerREF.GetRace() == NordRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceNordMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceNordMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceNordFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceNordFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == OrcRace || PlayerREF.GetRace() == OrcRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceOrcMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceOrcMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceOrcFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceOrcFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == RedguardRace || PlayerREF.GetRace() == RedguardRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceRedguardMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceRedguardMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceRedguardFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceRedguardFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	ElseIf PlayerREF.GetRace() == WoodElfRace || PlayerREF.GetRace() == WoodElfRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceWoodElfMaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceWoodElfMaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		Else ; Female
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycRaceWoodElfFemaleDSPMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			Else
				aiButtonChoice1 = _sycRaceWoodElfFemaleMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
			EndIf
		EndIf
	;## Custom Races ##
	Else
		aiButtonChoice1 = _sycRaceCustomMSG.Show(fHealth, fMagicka, fStamina, fCarryWeight)
	Endif
	;## Button Choices ##
	If aiButtonChoice1 == 0  ; Change Race
		ShowRaceMenu()
		WaitMenuMode(0.1)	; Need to wait for showracemenu to close
		RegisterForUpdate(0.1)	; Less than this and double menu bug will appear
		GoToState("WaitForShowRaceMenu")	; Reset Variables then Re-Initialize CCO Menu
	ElseIf aiButtonChoice1 == 1 ; Continue
		ChooseBirthsignMenu()
	EndIf
EndFunction


;### Choose Birthsign Menu Function ###
;---------------------------------------------------------------------------------------------------
; This function shows the Choose Birthsign Menu
Function ChooseBirthsignMenu(Int aiMessageToDisplay = 0, Int aiButtonChoice1 = 0, Bool abMenu = True)
	; Set Default Menu Choices
	iBirthsign = -1
	While abMenu		
		If aiButtonChoice1 == -1 ; Can prevent problems if recycling aiButtonChoice1
		;## [0] Choose Your Birthsign Set 1 ##
		ElseIf aiMessageToDisplay == 0
			aiButtonChoice1 = _sycChooseBirthsign1MSG.Show()		
			If aiButtonChoice1 == 0	; Apprentice
				aiButtonChoice1 = _sycBirthsignApprenticeMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 0
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 1	; Atronach
				aiButtonChoice1 = _sycBirthsignAtronachMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 1
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf		
			ElseIf aiButtonChoice1 == 2	; Lady
				aiButtonChoice1 = _sycBirthsignLadyMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 2
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 3	; Lord
				aiButtonChoice1 = _sycBirthsignLordMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 3
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 4	; More
				aiMessageToDisplay = 1			
			ElseIf aiButtonChoice1 == 5	; Back
				abMenu = False	; Stop While Loop and close menu
				GoToState("ResetVars")	; This will reset base stats and then go to the Choose Race Menu
			EndIf
		;## [1] Choose Your Birthsign Set 2 ##
		ElseIf aiMessageToDisplay == 1
			aiButtonChoice1 = _sycChooseBirthsign2MSG.Show()		
			If aiButtonChoice1 == 0	; Lover
				aiButtonChoice1 = _sycBirthsignLoverMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 4
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 1
				EndIf
			ElseIf aiButtonChoice1 == 1	; Mage
				aiButtonChoice1 = _sycBirthsignMageMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 5
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 1
				EndIf		
			ElseIf aiButtonChoice1 == 2	; Ritual
				aiButtonChoice1 = _sycBirthsignRitualMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 6
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 1
				EndIf
			ElseIf aiButtonChoice1 == 3	; Serpent
				aiButtonChoice1 = _sycBirthsignSerpentMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 7
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 1
				EndIf
			ElseIf aiButtonChoice1 == 4	; Shadow
				aiButtonChoice1 = _sycBirthsignShadowMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 8
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 1
				EndIf
			ElseIf aiButtonChoice1 == 5	; More
				aiMessageToDisplay = 2			
			ElseIf aiButtonChoice1 == 6	; Back
				abMenu = False	; Stop While Loop and close menu
				GoToState("ResetVars")	; This will reset base stats and then go to the Choose Race Menu
			EndIf
		;## [2] Choose Your Birthsign Set 3 ##
		ElseIf aiMessageToDisplay == 2
			aiButtonChoice1 = _sycChooseBirthsign3MSG.Show()		
			If aiButtonChoice1 == 0	; Steed
				aiButtonChoice1 = _sycBirthsignSteedMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 9
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 2
				EndIf
			ElseIf aiButtonChoice1 == 1	; Thief
				aiButtonChoice1 = _sycBirthsignThiefMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 10
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 2
				EndIf		
			ElseIf aiButtonChoice1 == 2	; Tower
				aiButtonChoice1 = _sycBirthsignTowerMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 11
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 2
				EndIf
			ElseIf aiButtonChoice1 == 3	; Warrior
				aiButtonChoice1 = _sycBirthsignWarriorMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 12
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 2
				EndIf
			ElseIf aiButtonChoice1 == 4	; None
				aiButtonChoice1 = _sycBirthsignNoneMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					iBirthsign = 13
					abMenu = False
					ChooseClassMenu()
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 2
				EndIf
			ElseIf aiButtonChoice1 == 5	; More
				aiMessageToDisplay = 0	
			ElseIf aiButtonChoice1 == 6	; Back
				abMenu = False	; Stop While Loop and close menu
				GoToState("ResetVars")	; This will reset base stats and then go to the Choose Race Menu
			EndIf

			
		EndIf
	EndWhile
EndFunction


;### Choose Class Menu Function ###
;---------------------------------------------------------------------------------------------------
; This function shows the Choose Class Menu
Function ChooseClassMenu(Int aiMessageToDisplay = 0, Int aiButtonChoice1 = 0, Bool abMenu = True)
	; Set Default Menu Choices
	iSpecialization = -1
	iAttribute = -1
	iMajorSkill1 = -1
	iMajorSkill2 = -1
	iMajorSkill3 = -1
	iMajorSkill4 = -1
	iMajorSkill5 = -1
	iMajorSkill6 = -1
	While abMenu		
		If aiButtonChoice1 == -1 ; Can prevent problems if recycling aiButtonChoice1
		
		;## [0] Choose Your Class ##
		ElseIf aiMessageToDisplay == 0
			aiButtonChoice1 = _sycChooseClassMSG.Show()		
			If aiButtonChoice1 == 0	; Combat Classes
				aiMessageToDisplay = 1
			ElseIf aiButtonChoice1 == 1	; Magic Classes
				aiMessageToDisplay = 2
			ElseIf aiButtonChoice1 == 2	; Stealth Classes
				aiMessageToDisplay = 3
			ElseIf aiButtonChoice1 == 3	; Custom Class
				aiMessageToDisplay = 4
			ElseIf aiButtonChoice1 == 4	; Back
				abMenu = False	; Stop While Loop and close menu
				ChooseBirthsignMenu()
			EndIf
				
		;## [1] Combat Classes ##
		ElseIf aiMessageToDisplay == 1
			aiButtonChoice1 = _sycCombatClassesMSG.Show()
			If aiButtonChoice1 == 0 ; Archer
				aiButtonChoice1 = _sycClassArcherMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 0
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 3
					iMajorSkill3 = 4
					iMajorSkill4 = 11
					iMajorSkill5 = 13
					iMajorSkill6 = 16	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 1 ; Barbarian
				aiButtonChoice1 = _sycClassBarbarianMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 0
					iAttribute = 0
					iMajorSkill1 = 0
					iMajorSkill2 = 1
					iMajorSkill3 = 3
					iMajorSkill4 = 4
					iMajorSkill5 = 5
					iMajorSkill6 = 13	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 2 ; Crusader
				aiButtonChoice1 = _sycClassCrusaderMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 0
					iAttribute = 0	
					iMajorSkill1 = 1
					iMajorSkill2 = 2
					iMajorSkill3 = 3
					iMajorSkill4 = 5
					iMajorSkill5 = 8
					iMajorSkill6 = 11	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 3 ; Knight
				aiButtonChoice1 = _sycClassKnightMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 0
					iAttribute = 0		
					iMajorSkill1 = 1
					iMajorSkill2 = 2
					iMajorSkill3 = 3
					iMajorSkill4 = 5
					iMajorSkill5 = 10
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 4 ; Rogue
				aiButtonChoice1 = _sycClassRogueMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 0
					iAttribute = 2
					iMajorSkill1 = 1
					iMajorSkill2 = 3
					iMajorSkill3 = 10
					iMajorSkill4 = 12
					iMajorSkill5 = 13
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 5 ; Scout
				aiButtonChoice1 = _sycClassScoutMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 0
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 1
					iMajorSkill3 = 3
					iMajorSkill4 = 4
					iMajorSkill5 = 12
					iMajorSkill6 = 13	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 6 ; Warrior
				aiButtonChoice1 = _sycClassWarriorMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 0
					iAttribute = 0	
					iMajorSkill1 = 0
					iMajorSkill2 = 1
					iMajorSkill3 = 2
					iMajorSkill4 = 3
					iMajorSkill5 = 4
					iMajorSkill6 = 5	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 7	; Back
				aiMessageToDisplay = 0
			EndIf
		;## [2] Magic Classes ##
		ElseIf aiMessageToDisplay == 2	; Magic Classes
			aiButtonChoice1 = _sycMagicClassesMSG.Show()
			If aiButtonChoice1 == 0 ; Battlemage
				aiButtonChoice1 = _sycClassBattlemageMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 1
					iAttribute = 1
					iMajorSkill1 = 3
					iMajorSkill2 = 6
					iMajorSkill3 = 7
					iMajorSkill4 = 8
					iMajorSkill5 = 9
					iMajorSkill6 = 12	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 1 ; Healer
				aiButtonChoice1 = _sycClassHealerMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 1
					iAttribute = 1
					iMajorSkill1 = 6
					iMajorSkill2 = 8
					iMajorSkill3 = 10
					iMajorSkill4 = 11
					iMajorSkill5 = 12
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 2 ; Mage
				aiButtonChoice1 = _sycClassMageMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 1
					iAttribute = 1
					iMajorSkill1 = 6
					iMajorSkill2 = 7
					iMajorSkill3 = 8
					iMajorSkill4 = 9
					iMajorSkill5 = 10
					iMajorSkill6 = 11	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 3 ; Nightblade
				aiButtonChoice1 = _sycClassNightbladeMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 1
					iAttribute = 1
					iMajorSkill1 = 3
					iMajorSkill2 = 6
					iMajorSkill3 = 8
					iMajorSkill4 = 11
					iMajorSkill5 = 13
					iMajorSkill6 = 16	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 4 ; Sorcerer
				aiButtonChoice1 = _sycClassSorcererMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 1
					iAttribute = 1
					iMajorSkill1 = 2
					iMajorSkill2 = 6
					iMajorSkill3 = 7
					iMajorSkill4 = 8
					iMajorSkill5 = 9
					iMajorSkill6 = 11	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 5 ; Spellsword
				aiButtonChoice1 = _sycClassSpellswordMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 1
					iAttribute = 0
					iMajorSkill1 = 2
					iMajorSkill2 = 3
					iMajorSkill3 = 6
					iMajorSkill4 = 8
					iMajorSkill5 = 10
					iMajorSkill6 = 11	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 6 ; Witchhunter
				aiButtonChoice1 = _sycClassWitchhunterMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 1
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 7
					iMajorSkill3 = 8
					iMajorSkill4 = 9
					iMajorSkill5 = 12
					iMajorSkill6 = 14	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 7	; Back
				aiMessageToDisplay = 0				
			EndIf
		;## [3] Stealth Classes ##
		ElseIf aiMessageToDisplay == 3	; Stealth Classes
			aiButtonChoice1 = _sycStealthClassesMSG.Show()
			If aiButtonChoice1 == 0 ; Acrobat
				aiButtonChoice1 = _sycClassAcrobatMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 2
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 1
					iMajorSkill3 = 3
					iMajorSkill4 = 14
					iMajorSkill5 = 16
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 1 ; Agent
				aiButtonChoice1 = _sycClassAgentMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 2
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 10
					iMajorSkill3 = 14
					iMajorSkill4 = 15
					iMajorSkill5 = 16
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 2 ; Assassin
				aiButtonChoice1 = _sycClassAssassinMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 2
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 3
					iMajorSkill3 = 12
					iMajorSkill4 = 13
					iMajorSkill5 = 14
					iMajorSkill6 = 16	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 3 ; Bard
				aiButtonChoice1 = _sycClassBardMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 2
					iAttribute = 2
					iMajorSkill1 = 1
					iMajorSkill2 = 3
					iMajorSkill3 = 10
					iMajorSkill4 = 12
					iMajorSkill5 = 13
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 4 ; Monk
				aiButtonChoice1 = _sycClassMonkMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 2
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 1
					iMajorSkill3 = 6
					iMajorSkill4 = 11
					iMajorSkill5 = 14
					iMajorSkill6 = 16	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 5 ; Pilgrim
				aiButtonChoice1 = _sycClassPilgrimMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 2
					iAttribute = 0
					iMajorSkill1 = 1
					iMajorSkill2 = 4
					iMajorSkill3 = 5
					iMajorSkill4 = 13
					iMajorSkill5 = 14
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 6 ; Thief
				aiButtonChoice1 = _sycClassThiefMSG.Show()
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 5
					iSpecialization = 2
					iAttribute = 2
					iMajorSkill1 = 0
					iMajorSkill2 = 13
					iMajorSkill3 = 14
					iMajorSkill4 = 15
					iMajorSkill5 = 16
					iMajorSkill6 = 17	
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 7	; Back
				aiMessageToDisplay = 0				
			EndIf
		;## [4] Create Custom Class ##
		ElseIf aiMessageToDisplay == 4	; Custom Class
			abMenu = False	; Stop While Loop and close menu
			CreateCustomClassMenu()
			
		;## [5] Close Menu (Standard Classes Only) ##
		ElseIf aiMessageToDisplay == 5
			abMenu = False	; Stop While Loop and close menu
			GoToState("AssignClassStats")
		EndIf
	EndWhile
EndFunction


;### Create Custom Class Menu Function ###
;---------------------------------------------------------------------------------------------------
; This function shows the Create Custom Class Creation Menu
Function CreateCustomClassMenu(Int aiMessageToDisplay = 0, Int aiButtonChoice1 = 0, Int aiButtonChoice2 = 0, Bool abMenu = True)
	; Set Default Menu Choices
	iSpecialization = -1
	iAttribute = -1
	iMajorSkill1 = -1
	iMajorSkill2 = -1
	iMajorSkill3 = -1
	iMajorSkill4 = -1
	iMajorSkill5 = -1
	iMajorSkill6 = -1
	While abMenu
		If aiButtonChoice1 == -1 ; Can prevent problems if recycling aiButtonChoice1 and aiButtonChoice2
		ElseIf aiButtonChoice2 == -1
		;## [0] Choose A Specialization ##
		ElseIf aiMessageToDisplay == 0
			If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
				aiButtonChoice1 = _sycChooseSpecializationDSPMSG.Show()
			Else
				aiButtonChoice1 = _sycChooseSpecializationMSG.Show()
			EndIf
			iSpecialization = aiButtonChoice1	; Record Choice
			If aiButtonChoice1 == 0 ; Combat
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycCombatSpecializationDSPMSG.Show()
				Else
					aiButtonChoice1 = _sycCombatSpecializationMSG.Show()
				EndIf
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 1
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 1 ; Magic
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycMagicSpecializationDSPMSG.Show()
				Else
					aiButtonChoice1 = _sycMagicSpecializationMSG.Show()
				EndIf
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 1
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			ElseIf aiButtonChoice1 == 2 ; Stealth
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycStealthSpecializationDSPMSG.Show()
				Else
					aiButtonChoice1 = _sycStealthSpecializationMSG.Show()
				EndIf
				If aiButtonChoice1 == 0 ; Choose
					aiMessageToDisplay = 1
				ElseIf aiButtonChoice1 == 1 ; Back
					aiMessageToDisplay = 0
				EndIf
			;## Back to Class Menu ##
			ElseIf aiButtonChoice1 == 3 ; Back
				abMenu = False	; Stop While Loop and close menu
				ChooseClassMenu()
			EndIf
		;## [1] Choose A Favored Attribute ##
		ElseIf aiMessageToDisplay == 1
			aiButtonChoice1 = _sycChooseAttributeMSG.Show()
			iAttribute = aiButtonChoice1	; Record Choice
			If aiButtonChoice1 < 3	; Health, Magic, Stamina
				aiMessageToDisplay = 2
			ElseIf aiButtonChoice1 == 3 ; Back
				aiMessageToDisplay = 0
			EndIf
		;## [2-7] Choose Your Major Skills (6 Left) ##
		ElseIf aiMessageToDisplay <= 7
			; Show different message depending on how many skills left to pick
			If aiMessageToDisplay == 2
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycChooseMajorSkill1DSPMSG.Show()
				Else
					aiButtonChoice1 = _sycChooseMajorSkill1MSG.Show()
				EndIf
			ElseIf aiMessageToDisplay == 3
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycChooseMajorSkill2DSPMSG.Show()
				Else
					aiButtonChoice1 = _sycChooseMajorSkill2MSG.Show()
				EndIf
			ElseIf aiMessageToDisplay == 4
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycChooseMajorSkill3DSPMSG.Show()
				Else
					aiButtonChoice1 = _sycChooseMajorSkill3MSG.Show()
				EndIf
			ElseIf aiMessageToDisplay == 5
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycChooseMajorSkill4DSPMSG.Show()
				Else
					aiButtonChoice1 = _sycChooseMajorSkill4MSG.Show()
				EndIf
			ElseIf aiMessageToDisplay == 6
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycChooseMajorSkill5DSPMSG.Show()				
				Else
					aiButtonChoice1 = _sycChooseMajorSkill5MSG.Show()				
				EndIf
			ElseIf aiMessageToDisplay == 7
				If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
					aiButtonChoice1 = _sycChooseMajorSkill6DSPMSG.Show()
				Else
					aiButtonChoice1 = _sycChooseMajorSkill6MSG.Show()
				EndIf
			EndIf
			;## Combat Skills ##
			If aiButtonChoice1 == 0	; Combat Skills
				aiButtonChoice1 = _sycCombatSkillsMSG.Show()
				If aiButtonChoice1 == 0 ; Archery
					aiButtonChoice2 = _sycSkillArcheryMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1	
						EndIf
						aiMessageToDisplay += 1						
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf
				ElseIf aiButtonChoice1 == 1	; Block
					aiButtonChoice2 = _sycSkillBlockMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 2	; Heavy Armor
					aiButtonChoice2 = _sycSkillHeavyArmorMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 3	; One-handed
					aiButtonChoice2 = _sycSkillOneHandedMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 4	; Smithing
					aiButtonChoice2 = _sycSkillSmithingMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 5	; Two-handed
					aiButtonChoice2 = _sycSkillTwoHandedMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 6	; Back			
				EndIf
			;## Magic Skills ##
			ElseIf aiButtonChoice1 == 1	; Magic Skills
				aiButtonChoice1 = _sycMagicSkillsMSG.Show()
				If aiButtonChoice1 == 0 ; Alteration
					aiButtonChoice2 = _sycSkillAlterationMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 6	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 6	
						EndIf
						aiMessageToDisplay += 1						
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf
				ElseIf aiButtonChoice1 == 1	; Conjuration
					aiButtonChoice2 = _sycSkillConjurationMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 6	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 6	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 2	; Destruction
					aiButtonChoice2 = _sycSkillDestructionMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 6	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 6	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 3	; Enchantment
					aiButtonChoice2 = _sycSkillEnchantingMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 6	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 6	
						EndIf
						aiMessageToDisplay += 1
						ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 4	; Illusion
					aiButtonChoice2 = _sycSkillIllusionMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 6	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 6	
						EndIf
						aiMessageToDisplay += 1
						ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 5	; Restoration
					aiButtonChoice2 = _sycSkillRestorationMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 6
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 6	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 6	
						EndIf
						aiMessageToDisplay += 1
						ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 6	; Back			
				EndIf
			;## Stealth Skills ##			
			ElseIf aiButtonChoice1 == 2	; Stealth Skills
				aiButtonChoice1 = _sycStealthSkillsMSG.Show()	
				If aiButtonChoice1 == 0 ; Alchemy
					aiButtonChoice2 = _sycSkillAlchemyMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 12	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 12	
						EndIf
						aiMessageToDisplay += 1						
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf
				ElseIf aiButtonChoice1 == 1	; Light Armor
					aiButtonChoice2 = _sycSkillLightArmorMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 12	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 12	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 2	; Lockpicking
					aiButtonChoice2 = _sycSkillLockpickingMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 12	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 12	
						EndIf
						aiMessageToDisplay += 1	
					ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 3	; Pickpocketing
					aiButtonChoice2 = _sycSkillPickpocketMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 12	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 12	
						EndIf
						aiMessageToDisplay += 1
						ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 4	; Sneak
					aiButtonChoice2 = _sycSkillSneakMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 12	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 12	
						EndIf
						aiMessageToDisplay += 1
						ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 5	; Speech
					aiButtonChoice2 = _sycSkillSpeechMSG.Show()
					If aiButtonChoice2 == 0 ; Choose
						; Store as the 1st, 2nd, 3rd, 4th, 5th, or 6th, Major Skill choice
						If aiMessageToDisplay == 2
							iMajorSkill1 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 3
							iMajorSkill2 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 4
							iMajorSkill3 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 5
							iMajorSkill4 = aiButtonChoice1 + 12
						ElseIf aiMessageToDisplay == 6
							iMajorSkill5 = aiButtonChoice1 + 12	
						ElseIf aiMessageToDisplay == 7
							iMajorSkill6 = aiButtonChoice1 + 12	
						EndIf
						aiMessageToDisplay += 1
						ElseIf aiButtonChoice2 == 1 ; Back
					EndIf				
				ElseIf aiButtonChoice1 == 6	; Back			
				EndIf
			ElseIf aiButtonChoice1 == 3 ; Back
				aiMessageToDisplay -= 1
				; If going back, clear the last Major Skill selection
				If aiMessageToDisplay == 2
					iMajorSkill1 = -1
				ElseIf aiMessageToDisplay == 3
					iMajorSkill2 = -1
				ElseIf aiMessageToDisplay == 4
					iMajorSkill3 = -1
				ElseIf aiMessageToDisplay == 5
					iMajorSkill4 = -1
				ElseIf aiMessageToDisplay == 6
					iMajorSkill5 = -1	
				ElseIf aiMessageToDisplay == 7
					iMajorSkill6 = -1
				EndIf				
			EndIf
		
		;## [8] Close Menu ##
		ElseIf aiMessageToDisplay == 8
			abMenu = False	; Stop While Loop and close menu
			GoToState("AssignClassStats")
		EndIf
	EndWhile
EndFunction


;### Assign Specialization Function ###
;---------------------------------------------------------------------------------------------------
; Assign Specialization skills
Function AssignSpecialization()
	If iSpecialization == 0 ; Combat
		fBlockSkillModifier += 5
		fHeavyArmorSkillModifier += 5
		fMarksmanSkillModifier += 5
		fOneHandedSkillModifier += 5
		fSmithingSkillModifier += 5
		fTwoHandedSkillModifier += 5
	Elseif iSpecialization == 1 ; Magic
		fAlterationSkillModifier += 5
		fConjurationSkillModifier += 5
		fDestructionSkillModifier += 5
		fEnchantingSkillModifier += 5
		fIllusionSkillModifier += 5
		fRestorationSkillModifier += 5
	ElseIf iSpecialization == 2 ; Stealth
		fAlchemySkillModifier += 5
		fLightArmorSkillModifier += 5
		fLockpickingSkillModifier += 5
		fPickpocketSkillModifier += 5
		fSneakSkillModifier += 5
		fSpeechcraftSkillModifier += 5
	Endif
EndFunction


;### Assign Favored Attribute Function ###
;---------------------------------------------------------------------------------------------------
; Assigns favored attribute bonus
Function AssignFavoredAttribute()		
	If iAttribute == 0 ; Health
		fHealthModifier += 20
	ElseIf iAttribute == 1 ; Magicka
		fMagickaModifier += 20
	ElseIf iAttribute == 2 ; Stamina
		fStaminaModifier += 20
	EndIf
EndFunction


;### Assign Major Skills Function ###
;---------------------------------------------------------------------------------------------------
; Assign Major Skills skills
Function AssignMajorSkills()
	Int aiElement = 0
	Int[] arMajorSkills = New Int[6]	; Declare Major Skills Array that will be filled by aiMajorSkillX's
	arMajorSkills[0]= iMajorSkill1
	arMajorSkills[1]= iMajorSkill2
	arMajorSkills[2]= iMajorSkill3
	arMajorSkills[3]= iMajorSkill4
	arMajorSkills[4]= iMajorSkill5
	arMajorSkills[5]= iMajorSkill6
	aiElement = arMajorSkills.Length
	While aiElement > 0
		aiElement -= 1
		; Combat Skills
		If arMajorSkills[aiElement] == 0	; Archery
			fMarksmanSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 1	; Block
			fBlockSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 2	; Heavy Armor
			fHeavyArmorSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 3	; One-Handed
			fOneHandedSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 4	; Smithing
			fSmithingSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 5	; TwoHanded
			fTwoHandedSkillModifier += 20
		; Magic Skills
		ElseIf arMajorSkills[aiElement] == 6	; Alteration
			fAlterationSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 7	; Conjuration
			fConjurationSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 8	; Destruction
			fDestructionSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 9	; Enchanting
			fEnchantingSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 10	; Illusion
			fIllusionSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 11	; Restoration
			fRestorationSkillModifier += 20
		; Stealth Skills
		ElseIf arMajorSkills[aiElement] == 12	; Alchemy
			fAlchemySkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 13	; Light Armor
			fLightArmorSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 14	; Lockpicking
			fLockpickingSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 15	; Pickpocket
			fPickpocketSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 16	; Sneak
			fSneakSkillModifier += 20
		ElseIf arMajorSkills[aiElement] == 17	; Speech
			fSpeechcraftSkillModifier += 20
		EndIf
	EndWhile
EndFunction


;### Apply Birthsigns Function ###
;---------------------------------------------------------------------------------------------------
; Adds Birthsigns to the player
Function ApplyBirthsign()
	If iBirthsign != 13
		UnapplyBirthsign()	; If a birthsign is selected, remove existing standing stone bonuses
	EndIf
	If iBirthsign == 0	; Apprentice
		PlayerREF.AddSpell(DoomApprenticeAbility, False)
		PlayerREF.AddSpell(DoomApprenticeNegativeAbility, False)	
	ElseIf iBirthsign == 1	; Atronach
		PlayerREF.AddSpell(DoomAtronachAbility, False)	
	ElseIf iBirthsign == 2	; Lady
		PlayerREF.AddSpell(DoomLadyAbility, False)	
	ElseIf iBirthsign == 3	; Lord
		PlayerREF.AddSpell(DoomLordAbility, False)	
	ElseIf iBirthsign == 4	; Lover
		PlayerREF.RemoveSpell(Rested)
		PlayerREF.RemoveSpell(WellRested)
		PlayerREF.RemoveSpell(MarriageRested)
		PlayerREF.AddSpell(DoomLoverAbility, False)	
	ElseIf iBirthsign == 5	; Mage
		PlayerREF.AddSpell(DoomMageAbility, False)	
	ElseIf iBirthsign == 6	; Ritual
		PlayerREF.AddSpell(DoomRitualAbility, False)
		PlayerREF.AddPerk(DoomRitualPerk)	
	ElseIf iBirthsign == 7	; Serpent
		PlayerREF.AddSpell(DoomSerpentAbility, False)	
	ElseIf iBirthsign == 8	; Shadow
		PlayerREF.AddSpell(DoomShadowAbility, False)
	ElseIf iBirthsign == 9	; Steed
		PlayerREF.AddSpell(DoomSteedAbility, False)	
	ElseIf iBirthsign == 10	; Thief
		PlayerREF.AddSpell(DoomThiefAbility, False)	
	ElseIf iBirthsign == 11	; Tower
		PlayerREF.AddSpell(DoomTowerAbility, False)	
	ElseIf iBirthsign == 12	; Warrior
		PlayerREF.AddSpell(DoomWarriorAbility, False)	
	ElseIf iBirthsign == 13	; None
		; Do Nothing
	EndIf
EndFunction


;### Apply Attributes Function ###
;---------------------------------------------------------------------------------------------------
Function ApplyAttributes()
	;## Apply Attributes ##
	Float fTemp = PlayerREF.GetBaseAV("Health")
	PlayerREF.SetAV("Health", PlayerREF.GetBaseAV("Health") + fHealthModifier)
	PlayerREF.SetAV("Magicka", PlayerREF.GetBaseAV("Magicka") + fMagickaModifier)
	PlayerREF.SetAV("Stamina", PlayerREF.GetBaseAV("Stamina") + fStaminaModifier)
EndFunction


;### Apply Skill Values Function ###
;---------------------------------------------------------------------------------------------------
Function ApplySkillValues()	
	; Sets all starting skills to level 5 before adding modifiers. Current skill level taken into account for existing characters.
	; Racial skill bonuses are derived from the editor for compatibility with mods that change racial skill bonuses
	Int iStartingSkillLevel = GetGameSettingInt("iAVDSkillStart")
	PlayerREF.SetAV("Alchemy", PlayerREF.GetBaseAV("Alchemy") - iStartingSkillLevel + 5 + fAlchemySkillModifier)
	PlayerREF.SetAV("Alteration", PlayerREF.GetBaseAV("Alteration") - iStartingSkillLevel + 5 + fAlterationSkillModifier)
	PlayerREF.SetAV("Block", PlayerREF.GetBaseAV("Block") - iStartingSkillLevel + 5 + fBlockSkillModifier)
	PlayerREF.SetAV("Conjuration", PlayerREF.GetBaseAV("Conjuration") - iStartingSkillLevel + 5 + fConjurationSkillModifier)
	PlayerREF.SetAV("Destruction", PlayerREF.GetBaseAV("Destruction") - iStartingSkillLevel + 5 + fDestructionSkillModifier)
	PlayerREF.SetAV("Enchanting", PlayerREF.GetBaseAV("Enchanting") - iStartingSkillLevel + 5 + fEnchantingSkillModifier)
	PlayerREF.SetAV("HeavyArmor", PlayerREF.GetBaseAV("HeavyArmor") - iStartingSkillLevel + 5 + fHeavyArmorSkillModifier)
	PlayerREF.SetAV("Illusion", PlayerREF.GetBaseAV("Illusion") - iStartingSkillLevel + 5 + fIllusionSkillModifier)
	PlayerREF.SetAV("LightArmor", PlayerREF.GetBaseAV("LightArmor") - iStartingSkillLevel + 5 + fLightArmorSkillModifier)
	PlayerREF.SetAV("Lockpicking", PlayerREF.GetBaseAV("Lockpicking") - iStartingSkillLevel + 5 + fLockpickingSkillModifier)
	PlayerREF.SetAV("Marksman", PlayerREF.GetBaseAV("Marksman") - iStartingSkillLevel + 5 + fMarksmanSkillModifier)
	PlayerREF.SetAV("OneHanded", PlayerREF.GetBaseAV("OneHanded") - iStartingSkillLevel + 5 + fOneHandedSkillModifier)
	PlayerREF.SetAV("Pickpocket", PlayerREF.GetBaseAV("Pickpocket") - iStartingSkillLevel + 5 + fPickpocketSkillModifier)
	PlayerREF.SetAV("Restoration", PlayerREF.GetBaseAV("Restoration") - iStartingSkillLevel + 5 + fRestorationSkillModifier)
	PlayerREF.SetAV("Smithing", PlayerREF.GetBaseAV("Smithing") - iStartingSkillLevel + 5 + fSmithingSkillModifier)
	PlayerREF.SetAV("Sneak", PlayerREF.GetBaseAV("Sneak") - iStartingSkillLevel + 5 + fSneakSkillModifier)
	PlayerREF.SetAV("Speechcraft", PlayerREF.GetBaseAV("Speechcraft") - iStartingSkillLevel + 5 + fSpeechcraftSkillModifier)
	PlayerREF.SetAV("TwoHanded", PlayerREF.GetBaseAV("TwoHanded") - iStartingSkillLevel + 5 + fTwoHandedSkillModifier)
EndFunction


;---------------------------------------------------------------------------------------------------
;### UPGRADE/UNINSTALL FUNCTIONS ###
;---------------------------------------------------------------------------------------------------

;### Uninstall CCO Function ###
;---------------------------------------------------------------------------------------------------
Function UninstallCCO(Int aiButtonChoice1 = -1)
	If bCCODisabledOnCharacter == True	; Don't run uninstaller if CCO is disabled on character
		; Do Nothing
	Else
		; Check whether any CCO menu choices have been selected
		If (iSpecialization + iAttribute + iMajorSkill1 + iMajorSkill2 + iMajorSkill3 + iMajorSkill4 + iMajorSkill5 + iMajorSkill6) <= 0
			_sycCCOUninstallerActivatedByAccidentMSG.Show()
			VersionControl()
		Else	; Choices made
			aiButtonChoice1 = _sycConfirmUninstallCCOMSG.Show()
			If aiButtonChoice1 == 0	; Yes
				Notification("Character Creation Overhaul is uninstalling. Please wait...")
				If fVersion <= 1.20
					UninstallCCOV120()
				ElseIf fVersion <= 1.32
					UninstallCCOCurrentVersion()
				Else
					MessageBox("ERROR: CCO Version Not Recognized.")
				EndIf
				;## Clear All Variables ##
				; Clear all variables incase user re-installs CCO later
				ResetBaseStats()
				ResetMenuChoices()
				ResetHiddenProperties()
				_sycCCOUninstallationCompleteMSG.Show()
				UnregisterForUpdate()
				Stop()
			ElseIf aiButtonChoice1 == 1	; No
				_sycCCOUninstallationCanceledMSG.Show()
				VersionControl()
			EndIf
		EndIf
	EndIf
EndFunction


;### Uninstall CCO v1.0.0 to v1.2.0 Function ###
;---------------------------------------------------------------------------------------------------
Function UninstallCCOV120()
	;## Unapply Modules ##
	DisableDynamicSkillProgressionV120()	; Deprecated
	DisableOblivionCarryWeights()
	;## Re-assign All Stats ##
	; Re-assign stats so they can be properly unapplied
	ResetBaseStats()
	AssignRaceStatsV120()	; Deprecated				
	AssignSpecialization()
	AssignFavoredAttribute()
	AssignMajorSkills()
	;## Unapply All Stats ##
	UnapplyBirthsign()
	UnapplyAttributes()
	UnapplyCarryWeightV120()	; Deprecated
	UnapplySkillValues()
	ResetBaseStats()	; Reset stats after unapplying them
EndFunction

;### Uninstall CCO v1.3.0 Function ###
;---------------------------------------------------------------------------------------------------
Function UninstallCCOCurrentVersion()
	;## Unapply Modules ##
	UnapplyModules()
	;## Re-assign All Stats ##
	; Re-assign stats so they can be properly unapplied
	ResetBaseStats()
	AssignSpecialization()
	AssignFavoredAttribute()
	AssignMajorSkills()
	;## Unapply All Stats ##
	UnapplyBirthsign()
	UnapplyAttributes()
	UnapplySkillValues()
	RemoveItems()
EndFunction


;### Unapply Birthsigns Function ###
;---------------------------------------------------------------------------------------------------
Function UnapplyBirthsign()
	PlayerREF.RemoveSpell(DoomApprenticeAbility)
	PlayerREF.RemoveSpell(DoomApprenticeNegativeAbility)
	PlayerREF.RemoveSpell(DoomAtronachAbility)		
	PlayerREF.RemoveSpell(DoomLadyAbility)	
	PlayerREF.RemoveSpell(DoomLordAbility)	
	PlayerREF.RemoveSpell(DoomLoverAbility)
	PlayerREF.RemoveSpell(DoomMageAbility)	
	PlayerREF.RemoveSpell(DoomRitualAbility)	
	PlayerREF.RemoveSpell(DoomSerpentAbility)	
	PlayerREF.RemoveSpell(DoomShadowAbility)	
	PlayerREF.RemoveSpell(DoomSteedAbility)	
	PlayerREF.RemoveSpell(DoomThiefAbility)	
	PlayerREF.RemoveSpell(DoomTowerAbility)	
	PlayerREF.RemoveSpell(DoomWarriorAbility)	
EndFunction


;### Unapply Attributes Function ###
;---------------------------------------------------------------------------------------------------
Function UnapplyAttributes()
	PlayerREF.SetAV("Health", PlayerREF.GetBaseAV("Health") - fHealthModifier)
	PlayerREF.SetAV("Magicka", PlayerREF.GetBaseAV("Magicka") - fMagickaModifier)
	PlayerREF.SetAV("Stamina", PlayerREF.GetBaseAV("Stamina") - fStaminaModifier)
EndFunction


;### Unapply Skill Values Function ###
;---------------------------------------------------------------------------------------------------
Function UnapplySkillValues()
	Int iStartingSkillLevel = GetGameSettingInt("iAVDSkillStart")
	PlayerREF.SetAV("Alchemy", PlayerREF.GetBaseAV("Alchemy") + iStartingSkillLevel - 5 - fAlchemySkillModifier)
	PlayerREF.SetAV("Alteration", PlayerREF.GetBaseAV("Alteration") + iStartingSkillLevel - 5 - fAlterationSkillModifier)
	PlayerREF.SetAV("Block", PlayerREF.GetBaseAV("Block") + iStartingSkillLevel - 5 - fBlockSkillModifier)
	PlayerREF.SetAV("Conjuration", PlayerREF.GetBaseAV("Conjuration") + iStartingSkillLevel - 5 - fConjurationSkillModifier)
	PlayerREF.SetAV("Destruction", PlayerREF.GetBaseAV("Destruction") + iStartingSkillLevel - 5 - fDestructionSkillModifier)
	PlayerREF.SetAV("Enchanting", PlayerREF.GetBaseAV("Enchanting") + iStartingSkillLevel - 5 - fEnchantingSkillModifier)
	PlayerREF.SetAV("HeavyArmor", PlayerREF.GetBaseAV("HeavyArmor") + iStartingSkillLevel - 5 - fHeavyArmorSkillModifier)
	PlayerREF.SetAV("Illusion", PlayerREF.GetBaseAV("Illusion") + iStartingSkillLevel - 5 - fIllusionSkillModifier)
	PlayerREF.SetAV("LightArmor", PlayerREF.GetBaseAV("LightArmor") + iStartingSkillLevel - 5 - fLightArmorSkillModifier)
	PlayerREF.SetAV("Lockpicking", PlayerREF.GetBaseAV("Lockpicking") + iStartingSkillLevel - 5 - fLockpickingSkillModifier)
	PlayerREF.SetAV("Marksman", PlayerREF.GetBaseAV("Marksman") + iStartingSkillLevel - 5 - fMarksmanSkillModifier)
	PlayerREF.SetAV("OneHanded", PlayerREF.GetBaseAV("OneHanded") + iStartingSkillLevel - 5 - fOneHandedSkillModifier)
	PlayerREF.SetAV("Pickpocket", PlayerREF.GetBaseAV("Pickpocket") + iStartingSkillLevel - 5 - fPickpocketSkillModifier)
	PlayerREF.SetAV("Restoration", PlayerREF.GetBaseAV("Restoration") + iStartingSkillLevel - 5 - fRestorationSkillModifier)
	PlayerREF.SetAV("Smithing", PlayerREF.GetBaseAV("Smithing") + iStartingSkillLevel - 5 - fSmithingSkillModifier)
	PlayerREF.SetAV("Sneak", PlayerREF.GetBaseAV("Sneak") + iStartingSkillLevel - 5 - fSneakSkillModifier)
	PlayerREF.SetAV("Speechcraft", PlayerREF.GetBaseAV("Speechcraft") + iStartingSkillLevel - 5 - fSpeechcraftSkillModifier)
	PlayerREF.SetAV("TwoHanded", PlayerREF.GetBaseAV("TwoHanded") + iStartingSkillLevel - 5 - fTwoHandedSkillModifier)
EndFunction


;### Unapply Modules Function ###
;---------------------------------------------------------------------------------------------------
; Used by the Uninstaller to unapply changes from optional CCO modules. 
Function UnapplyModules()
	DisableDiverseRacesAndGenders()
	DisableDynamicSkillProgression()
	DisableOblivionCarryWeights()
	DisablePermanentBirthsigns()
EndFunction


;### Remove Items Function ###
;---------------------------------------------------------------------------------------------------
Function RemoveItems(Int aiCount = 0)
	aiCount = PlayerREF.GetItemCount(_sycCCOBook)
	PlayerREF.RemoveItem(_sycCCOBook, aiCount, True)
EndFunction


;---------------------------------------------------------------------------------------------------
;### VERSION CONTROL FUNCTIONS ###
;---------------------------------------------------------------------------------------------------

;### Version Control Function ###
;---------------------------------------------------------------------------------------------------
; Upgrade CCO from previous versions
Function VersionControl(Int aiButtonChoice1 = -1)
	fLatestVersion = 1.32	;! Set Latest Version
	If bCCODisabledOnCharacter == True	; Don't run if CCO is disabled on character
		; Do Nothing
	Else
		; Check whether any CCO menu choices have been selected
		;## First Time Using CCO ##
		If (iSpecialization + iAttribute + iMajorSkill1 + iMajorSkill2 + iMajorSkill3 + iMajorSkill4 + iMajorSkill5 + iMajorSkill6) <= 0
			bShowEnableCCOPrompt = True
			bPlayOpenCCOMenuSound = True
			bToggleModuleNotificationsOn = True	; Only show notifications OnPlayerLoad
			RegisterForUpdate(1)	; Check for Race Menu every every 1 seconds
			GoToState("WaitForShowRaceMenu")
		;## Not First Run ##
		Else	; Choices Made
			If fVersion <= 1.10
				UpgradeCCOFromV110()
			ElseIf fVersion == 1.20
				UpgradeCCOFromV120()
			ElseIf fVersion == 1.30	; 1.3.0 does not need to be upgraded to 1.3.2
				bToggleModuleNotificationsOn = True	; Only show notifications OnPlayerLoad
				ToggleModules()	; Run every OnPlayerLoadGame except during first run and upgrades
			;## Version Is Up To Date ##
			ElseIf fVersion == fLatestVersion
				bToggleModuleNotificationsOn = True	; Only show notifications OnPlayerLoad
				ToggleModules()	; Run every OnPlayerLoadGame except during first run and upgrades
			Else
				MessageBox("ERROR: CCO Version Not Recognized.")
			EndIf
		EndIf
		fVersion = fLatestVersion
	EndIf
EndFunction


;### Upgrade CCO from v1.1.0 Function ###
;---------------------------------------------------------------------------------------------------
; Player must re-select birthsign and class when upgrading from v1.1.0
Function UpgradeCCOFromV110()
	_sycUpgradeCCOMSG.Show(fLatestVersion)
	Notification("Character Creation Overhaul is upgrading. Please wait...")
	UninstallCCOV120()
	;## Wait For ShowRaceMenu ##
	; Once all CCO stats are unapplied, open the CCO menu again
	bShowEnableCCOPrompt = True
	bPlayOpenCCOMenuSound = True
	bToggleModuleNotificationsOn = True
	RegisterForUpdate(1)
	GoToState("WaitForShowRaceMenu")
EndFunction


;### Upgrade CCO from v1.2.0 Function ###
;---------------------------------------------------------------------------------------------------
Function UpgradeCCOFromV120(Int aiButtonChoice1 = -1)
	aiButtonChoice1 = _sycUpgradeCCOOptionsMSG.Show(fLatestVersion)
	Notification("Character Creation Overhaul is upgrading. Please wait...")
	UninstallCCOV120()
	If aiButtonChoice1 == 0	; Keep Choices
		GoToState("AssignClassStats")	; Skip the ResetVars state to keep choices
	ElseIf aiButtonChoice1 == 1	; Respecialize
		;## Wait For ShowRaceMenu ##
		; Once all CCO stats are unapplied, open the CCO menu again
		bShowEnableCCOPrompt = True
		bPlayOpenCCOMenuSound = True
		bToggleModuleNotificationsOn = True		
		RegisterForUpdate(1)
		GoToState("WaitForShowRaceMenu")	
	EndIf
EndFunction


;---------------------------------------------------------------------------------------------------
;### MODULE FUNCTIONS ###
;---------------------------------------------------------------------------------------------------

;### Toggle Modules Function ###
;---------------------------------------------------------------------------------------------------
; Ativate/deactivate optional CCO modules by checking whether the relevant .esp is loaded
Function ToggleModules()
	;## Diverse Races And Genders ##
	If Game.GetFormFromFile(0x00000D62, "CCO - Diverse Races And Genders.esp")
		EnableDiverseRacesAndGenders()
	Else
		DisableDiverseRacesAndGenders()
	EndIf
	;## Dynamic Skill Rate Progression ##
	If Game.GetFormFromFile(0x00000D62, "CCO - Dynamic Skill Progression.esp")
		EnableDynamicSkillProgression()
	Else
		DisableDynamicSkillProgression()
	EndIf
	;## Oblivion Carry Weights ##
	If Game.GetFormFromFile(0x00000D62, "CCO - Oblivion Carry Weights.esp")
		EnableOblivionCarryWeights()
	Else
		DisableOblivionCarryWeights()
	EndIf
	;## Permanent Birthsigns ##
	If Game.GetFormFromFile(0x00000D62, "CCO - Permanent Birthsigns.esp")
		EnablePermanentBirthsigns()
	Else
		DisablePermanentBirthsigns()
	EndIf
	bToggleModuleNotificationsOn = False	; Stop showing notifications after OnPlayerLoad
EndFunction


;### Enable Diverse Races And Genders Function ###
;---------------------------------------------------------------------------------------------------
Function EnableDiverseRacesAndGenders()
	If bDiverseRaceAndGendersApplied == False	; Only enable if disabled
		bDiverseRaceAndGendersApplied = True
		If bToggleModuleNotificationsOn == True
			Notification("Enabling Diverse Races And Genders...")
		EndIf
		
		;## Reset Attribute Modifiers ##
		ResetAttributeAndCarryWeightModifiers()
		; Skill Rates are reset in EnableDynamicSkillProgression()
		
		;## Assign Diverse Races And Genders Stats ##
		AssignDiverseRacesAndGendersAttributes()
		
		;## Assign Favored Attribute ##
		AssignFavoredAttribute()
		
		;## Apply Attributes ##
		ApplyAttributes()
		
		;## Apply Carry Weight ##
		If fCarryWeightModifier == -50
			PlayerREF.AddSpell(_sycDecreasedCarryWeight50Ability, False)
		ElseIf fCarryWeightModifier == 30
			PlayerREF.AddSpell(_sycIncreasedCarryWeight30Ability, False)
		ElseIf fCarryWeightModifier == 50
			PlayerREF.AddSpell(_sycIncreasedCarryWeight50Ability, False)
		EndIf
		
	EndIf
EndFunction


;### Assign Diverse Races And Genders Stats Function ###
;---------------------------------------------------------------------------------------------------
Function AssignDiverseRacesAndGendersAttributes()
	ActorBase PlayerREFBase = PlayerREF.GetBaseObject() as ActorBase
	If PlayerREF.GetRace() == ArgonianRace || PlayerREF.GetRace() == ArgonianRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		EndIf
	ElseIf PlayerREF.GetRace() == BretonRace || PlayerREF.GetRace() == BretonRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += -10
			fCarryWeightModifier += -50
		EndIf			
	ElseIf PlayerREF.GetRace() == DarkElfRace || PlayerREF.GetRace() == DarkElfRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += 0
		EndIf
	ElseIf PlayerREF.GetRace() == HighElfRace || PlayerREF.GetRace() == HighElfRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += 0
			fStaminaModifier += 0
			fCarryWeightModifier += -50
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += -10	
			fCarryWeightModifier += -50
		EndIf			
	ElseIf PlayerREF.GetRace() == ImperialRace || PlayerREF.GetRace() == ImperialRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += 0
		EndIf			
	ElseIf PlayerREF.GetRace() == KhajiitRace || PlayerREF.GetRace() == KhajiitRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += 0	
			fCarryWeightModifier += -50
		EndIf
	ElseIf PlayerREF.GetRace() == NordRace || PlayerREF.GetRace() == NordRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 20
			fCarryWeightModifier += 50
		Else ; Female
			fHealthModifier += -20
			fMagickaModifier += -40
			fStaminaModifier += 20
			fCarryWeightModifier += 50
		EndIf			
	ElseIf PlayerREF.GetRace() == OrcRace || PlayerREF.GetRace() == OrcRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 30
			fCarryWeightModifier += 30
		Else ; Female
			fHealthModifier += 0
			fMagickaModifier += -20
			fStaminaModifier += 20
			fCarryWeightModifier += 30
		EndIf			
	ElseIf PlayerREF.GetRace() == RedguardRace || PlayerREF.GetRace() == RedguardRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 20
			fCarryWeightModifier += 50
		Else ; Female
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 10
			fCarryWeightModifier += 0
		EndIf
	ElseIf PlayerREF.GetRace() == WoodElfRace || PlayerREF.GetRace() == WoodElfRaceVampire
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += -50
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += -50
		EndIf
	Else
		; Custom Race
	Endif
EndFunction


;### Disable Diverse Races And Genders Function ###
;---------------------------------------------------------------------------------------------------
Function DisableDiverseRacesAndGenders()
	If bDiverseRaceAndGendersApplied == True	; Only disable if enabled
		bDiverseRaceAndGendersApplied = False
		If bToggleModuleNotificationsOn == True
			Notification("Disabling Diverse Races And Genders...")
		EndIf
		
		;## Unapply Attributes ##
		UnapplyAttributes()
		
		;## Reset Attribute Modifiers ##
		ResetAttributeAndCarryWeightModifiers()
		
		;## Assign Attributes ##
		AssignFavoredAttribute()

		;## Apply Attributes ##
		ApplyAttributes()

		;## Unapply Carry Weight ##
		PlayerREF.RemoveSpell(_sycDecreasedCarryWeight50Ability)
		PlayerREF.RemoveSpell(_sycIncreasedCarryWeight30Ability)
		PlayerREF.RemoveSpell(_sycIncreasedCarryWeight50Ability)
	
	EndIf
EndFunction


;### Enable Dynamic Skill Progression Function ###
;---------------------------------------------------------------------------------------------------
; Adds skill rate spells based on menu choices
Function EnableDynamicSkillProgression()
	If bDynamicSkillProgressionApplied == False	; Only enable if disabled
		bDynamicSkillProgressionApplied = True
		If bToggleModuleNotificationsOn == True
			Notification("Enabling Dynamic Skill Progression...")
		EndIf
		
		;## Reset Skill Rates ##
		ResetSkillRates()
		
		;## Assign Race Skill Rates ##
		If PlayerREF.GetRace() == ArgonianRace || PlayerREF.GetRace() == ArgonianRaceVampire
			fAlterationSkillRate += 0.05
			fLightArmorSkillRate += 0.05
			fLockpickingSkillRate += 0.10
			fPickpocketSkillRate += 0.05
			fRestorationSkillRate += 0.05
			fSneakSkillRate += 0.05
		ElseIf PlayerREF.GetRace() == BretonRace || PlayerREF.GetRace() == BretonRaceVampire
			fAlchemySkillRate += 0.05
			fAlterationSkillRate += 0.05
			fConjurationSkillRate += 0.10
			fIllusionSkillRate += 0.05
			fRestorationSkillRate += 0.05
			fSpeechcraftSkillRate += 0.05
		ElseIf PlayerREF.GetRace() == DarkElfRace || PlayerREF.GetRace() == DarkElfRaceVampire
			fAlchemySkillRate += 0.05
			fAlterationSkillRate += 0.05
			fDestructionSkillRate += 0.10
			fIllusionSkillRate += 0.05
			fLightArmorSkillRate += 0.05
			fSneakSkillRate += 0.05
		ElseIf PlayerREF.GetRace() == HighElfRace || PlayerREF.GetRace() == HighElfRaceVampire
			fAlterationSkillRate += 0.05
			fConjurationSkillRate += 0.05
			fDestructionSkillRate += 0.05
			fEnchantingSkillRate += 0.05
			fIllusionSkillRate += 0.10
			fRestorationSkillRate += 0.05
		ElseIf PlayerREF.GetRace() == ImperialRace || PlayerREF.GetRace() == ImperialRaceVampire
			fBlockSkillRate += 0.05
			fDestructionSkillRate += 0.05
			fEnchantingSkillRate += 0.05
			fHeavyArmorSkillRate += 0.05
			fOneHandedSkillRate += 0.05
			fRestorationSkillRate += 0.10
		ElseIf PlayerREF.GetRace() == KhajiitRace || PlayerREF.GetRace() == KhajiitRaceVampire
			fAlchemySkillRate += 0.05
			fMarksmanSkillRate += 0.05
			fLockpickingSkillRate += 0.05
			fOneHandedSkillRate += 0.05
			fPickpocketSkillRate += 0.05
			fSneakSkillRate += 0.10
		ElseIf PlayerREF.GetRace() == NordRace || PlayerREF.GetRace() == NordRaceVampire
			fBlockSkillRate += 0.05
			fLightArmorSkillRate += 0.05
			fOneHandedSkillRate += 0.05
			fSmithingSkillRate += 0.05
			fSpeechcraftSkillRate += 0.05
			fTwoHandedSkillRate += 0.10
		ElseIf PlayerREF.GetRace() == OrcRace || PlayerREF.GetRace() == OrcRaceVampire
			fBlockSkillRate += 0.05
			fEnchantingSkillRate += 0.05
			fHeavyArmorSkillRate += 0.10
			fOneHandedSkillRate += 0.05
			fSmithingSkillRate += 0.05
			fTwoHandedSkillRate += 0.05
		ElseIf PlayerREF.GetRace() == RedguardRace || PlayerREF.GetRace() == RedguardRaceVampire
			fAlterationSkillRate += 0.05
			fBlockSkillRate += 0.05
			fDestructionSkillRate += 0.05
			fMarksmanSkillRate += 0.05
			fOneHandedSkillRate += 0.10
			fSmithingSkillRate += 0.05
		ElseIf PlayerREF.GetRace() == WoodElfRace || PlayerREF.GetRace() == WoodElfRaceVampire
			fAlchemySkillRate += 0.05
			fLightArmorSkillRate += 0.05
			fMarksmanSkillRate += 0.10
			fLockpickingSkillRate += 0.05
			fPickpocketSkillRate += 0.05
			fSneakSkillRate += 0.05
		Else
			; Custom Race
		Endif
		
		;## Assign Specialization Skill Rates ##
		If iSpecialization == 0 ; Combat
			fBlockSkillRate += 0.05
			fHeavyArmorSkillRate += 0.05
			fMarksmanSkillRate += 0.05
			fOneHandedSkillRate += 0.05
			fSmithingSkillRate += 0.05
			fTwoHandedSkillRate += 0.05
		Elseif iSpecialization == 1 ; Magic
			fAlterationSkillRate += 0.05
			fConjurationSkillRate += 0.05
			fDestructionSkillRate += 0.05
			fEnchantingSkillRate += 0.05
			fIllusionSkillRate += 0.05
			fRestorationSkillRate += 0.05
		ElseIf iSpecialization == 2 ; Stealth
			fAlchemySkillRate += 0.05
			fLightArmorSkillRate += 0.05
			fLockpickingSkillRate += 0.05
			fPickpocketSkillRate += 0.05
			fSneakSkillRate += 0.05
			fSpeechcraftSkillRate += 0.05
		Endif
		
		;## Assign Major Skill Rates ##
		Int aiElement = 0
		Int[] arMajorSkills = New Int[6]	; Declare Major Skills Array that will be filled by aiMajorSkillX's
		arMajorSkills[0]= iMajorSkill1
		arMajorSkills[1]= iMajorSkill2
		arMajorSkills[2]= iMajorSkill3
		arMajorSkills[3]= iMajorSkill4
		arMajorSkills[4]= iMajorSkill5
		arMajorSkills[5]= iMajorSkill6
		aiElement = arMajorSkills.Length
		While aiElement > 0
			aiElement -= 1
			; Combat Skills
			If arMajorSkills[aiElement] == 0	; Archery
				fMarksmanSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 1	; Block
				fBlockSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 2	; Heavy Armor
				fHeavyArmorSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 3	; One-Handed
				fOneHandedSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 4	; Smithing
				fSmithingSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 5	; TwoHanded
				fTwoHandedSkillRate += 0.20
			; Magic Skills
			ElseIf arMajorSkills[aiElement] == 6	; Alteration
				fAlterationSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 7	; Conjuration
				fConjurationSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 8	; Destruction
				fDestructionSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 9	; Enchanting
				fEnchantingSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 10	; Illusion
				fIllusionSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 11	; Restoration
				fRestorationSkillRate += 0.20
			; Stealth Skills
			ElseIf arMajorSkills[aiElement] == 12	; Alchemy
				fAlchemySkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 13	; Light Armor
				fLightArmorSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 14	; Lockpicking
				fLockpickingSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 15	; Pickpocket
				fPickpocketSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 16	; Sneak
				fSneakSkillRate += 0.20
			ElseIf arMajorSkills[aiElement] == 17	; Speech
				fSpeechcraftSkillRate += 0.20
			EndIf
		EndWhile		
		
		;## Apply Skill Rates ##
		; Alchemy
		If fAlchemySkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateAlchemy105Perk)
		ElseIf fAlchemySkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateAlchemy110Perk)
		ElseIf fAlchemySkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateAlchemy115Perk)
		ElseIf fAlchemySkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateAlchemy120Perk)
		ElseIf fAlchemySkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateAlchemy125Perk)
		ElseIf fAlchemySkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateAlchemy130Perk)
		ElseIf fAlchemySkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateAlchemy135Perk)
		Endif
		; Alterations
		If fAlterationSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateAlteration105Perk)
		ElseIf fAlterationSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateAlteration110Perk)
		ElseIf fAlterationSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateAlteration115Perk)
		ElseIf fAlterationSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateAlteration120Perk)
		ElseIf fAlterationSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateAlteration125Perk)
		ElseIf fAlterationSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateAlteration130Perk)
		ElseIf fAlterationSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateAlteration135Perk)
		Endif	
		; Block
		If fBlockSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateBlock105Perk)
		ElseIf fBlockSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateBlock110Perk)
		ElseIf fBlockSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateBlock115Perk)
		ElseIf fBlockSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateBlock120Perk)
		ElseIf fBlockSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateBlock125Perk)
		ElseIf fBlockSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateBlock130Perk)
		ElseIf fBlockSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateBlock135Perk)
		Endif		
		; Conjuration
		If fConjurationSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateConjuration105Perk)
		ElseIf fConjurationSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateConjuration110Perk)
		ElseIf fConjurationSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateConjuration115Perk)
		ElseIf fConjurationSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateConjuration120Perk)
		ElseIf fConjurationSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateConjuration125Perk)
		ElseIf fConjurationSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateConjuration130Perk)
		ElseIf fConjurationSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateConjuration135Perk)
		Endif	
		; Destruction
		If fDestructionSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateDestruction105Perk)
		ElseIf fDestructionSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateDestruction110Perk)
		ElseIf fDestructionSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateDestruction115Perk)
		ElseIf fDestructionSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateDestruction120Perk)
		ElseIf fDestructionSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateDestruction125Perk)
		ElseIf fDestructionSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateDestruction130Perk)
		ElseIf fDestructionSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateDestruction135Perk)
		Endif		
		; Enchanting
		If fEnchantingSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateEnchanting105Perk)
		ElseIf fEnchantingSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateEnchanting110Perk)
		ElseIf fEnchantingSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateEnchanting115Perk)
		ElseIf fEnchantingSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateEnchanting120Perk)
		ElseIf fEnchantingSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateEnchanting125Perk)
		ElseIf fEnchantingSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateEnchanting130Perk)
		ElseIf fEnchantingSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateEnchanting135Perk)
		Endif	
		; Heavy Armor
		If fHeavyArmorSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateHeavyArmor105Perk)
		ElseIf fHeavyArmorSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateHeavyArmor110Perk)
		ElseIf fHeavyArmorSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateHeavyArmor115Perk)
		ElseIf fHeavyArmorSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateHeavyArmor120Perk)
		ElseIf fHeavyArmorSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateHeavyArmor125Perk)
		ElseIf fHeavyArmorSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateHeavyArmor130Perk)
		ElseIf fHeavyArmorSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateHeavyArmor135Perk)
		Endif	
		; Illusion
		If fIllusionSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateIllusion105Perk)
		ElseIf fIllusionSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateIllusion110Perk)
		ElseIf fIllusionSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateIllusion115Perk)
		ElseIf fIllusionSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateIllusion120Perk)
		ElseIf fIllusionSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateIllusion125Perk)
		ElseIf fIllusionSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateIllusion130Perk)
		ElseIf fIllusionSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateIllusion135Perk)
		Endif	
		; Light Armor
		If fLightArmorSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateLightArmor105Perk)
		ElseIf fLightArmorSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateLightArmor110Perk)
		ElseIf fLightArmorSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateLightArmor115Perk)
		ElseIf fLightArmorSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateLightArmor120Perk)
		ElseIf fLightArmorSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateLightArmor125Perk)
		ElseIf fLightArmorSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateLightArmor130Perk)
		ElseIf fLightArmorSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateLightArmor135Perk)
		Endif	
		; Lockpicking
		If fLockpickingSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateLockpicking105Perk)
		ElseIf fLockpickingSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateLockpicking110Perk)
		ElseIf fLockpickingSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateLockpicking115Perk)
		ElseIf fLockpickingSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateLockpicking120Perk)
		ElseIf fLockpickingSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateLockpicking125Perk)
		ElseIf fLockpickingSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateLockpicking130Perk)
		ElseIf fLockpickingSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateLockpicking135Perk)
		Endif	
		; Archery
		If fMarksmanSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateMarksman105Perk)
		ElseIf fMarksmanSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateMarksman110Perk)
		ElseIf fMarksmanSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateMarksman115Perk)
		ElseIf fMarksmanSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateMarksman120Perk)
		ElseIf fMarksmanSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateMarksman125Perk)
		ElseIf fMarksmanSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateMarksman130Perk)
		ElseIf fMarksmanSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateMarksman135Perk)
		Endif	
		; One-Handed
		If fOneHandedSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateOneHanded105Perk)
		ElseIf fOneHandedSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateOneHanded110Perk)
		ElseIf fOneHandedSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateOneHanded115Perk)
		ElseIf fOneHandedSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateOneHanded120Perk)
		ElseIf fOneHandedSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateOneHanded125Perk)
		ElseIf fOneHandedSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateOneHanded130Perk)
		ElseIf fOneHandedSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateOneHanded135Perk)
		Endif	
		; Pickpocket
		If fPickpocketSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRatePickpocket105Perk)
		ElseIf fPickpocketSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRatePickpocket110Perk)
		ElseIf fPickpocketSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRatePickpocket115Perk)
		ElseIf fPickpocketSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRatePickpocket120Perk)
		ElseIf fPickpocketSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRatePickpocket125Perk)
		ElseIf fPickpocketSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRatePickpocket130Perk)
		ElseIf fPickpocketSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRatePickpocket135Perk)
		Endif	
		; Restoration
		If fRestorationSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateRestoration105Perk)
		ElseIf fRestorationSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateRestoration110Perk)
		ElseIf fRestorationSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateRestoration115Perk)
		ElseIf fRestorationSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateRestoration120Perk)
		ElseIf fRestorationSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateRestoration125Perk)
		ElseIf fRestorationSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateRestoration130Perk)
		ElseIf fRestorationSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateRestoration135Perk)
		Endif	
		; Smithing
		If fSmithingSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateSmithing105Perk)
		ElseIf fSmithingSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateSmithing110Perk)
		ElseIf fSmithingSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateSmithing115Perk)
		ElseIf fSmithingSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateSmithing120Perk)
		ElseIf fSmithingSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateSmithing125Perk)
		ElseIf fSmithingSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateSmithing130Perk)
		ElseIf fSmithingSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateSmithing135Perk)
		Endif		
		; Sneak
		If fSneakSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateSneak105Perk)
		ElseIf fSneakSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateSneak110Perk)
		ElseIf fSneakSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateSneak115Perk)
		ElseIf fSneakSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateSneak120Perk)
		ElseIf fSneakSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateSneak125Perk)
		ElseIf fSneakSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateSneak130Perk)
		ElseIf fSneakSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateSneak135Perk)
		Endif		
		; Speech
		If fSpeechcraftSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateSpeechcraft105Perk)
		ElseIf fSpeechcraftSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateSpeechcraft110Perk)
		ElseIf fSpeechcraftSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateSpeechcraft115Perk)
		ElseIf fSpeechcraftSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateSpeechcraft120Perk)
		ElseIf fSpeechcraftSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateSpeechcraft125Perk)
		ElseIf fSpeechcraftSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateSpeechcraft130Perk)
		ElseIf fSpeechcraftSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateSpeechcraft135Perk)
		Endif		
		; Two-Handed
		If fTwoHandedSkillRate == 1.05
			PlayerREF.AddPerk(_sycSkillRateTwoHanded105Perk)
		ElseIf fTwoHandedSkillRate == 1.10
			PlayerREF.AddPerk(_sycSkillRateTwoHanded110Perk)
		ElseIf fTwoHandedSkillRate == 1.15
			PlayerREF.AddPerk(_sycSkillRateTwoHanded115Perk)
		ElseIf fTwoHandedSkillRate == 1.20
			PlayerREF.AddPerk(_sycSkillRateTwoHanded120Perk)
		ElseIf fTwoHandedSkillRate == 1.25
			PlayerREF.AddPerk(_sycSkillRateTwoHanded125Perk)
		ElseIf fTwoHandedSkillRate == 1.30
			PlayerREF.AddPerk(_sycSkillRateTwoHanded130Perk)
		ElseIf fTwoHandedSkillRate == 1.35
			PlayerREF.AddPerk(_sycSkillRateTwoHanded135Perk)
		Endif

	EndIf
EndFunction


;### Disable Dynamic Skill Progression Function ###
;---------------------------------------------------------------------------------------------------
Function DisableDynamicSkillProgression()
	If bDynamicSkillProgressionApplied == True	; Only disable if enabled
		bDynamicSkillProgressionApplied = False
		If bToggleModuleNotificationsOn == True
			Notification("Disabling Dynamic Skill Progression...")
		EndIf
		
		;## Reset Skill Rates ##
		ResetSkillRates()
		
		;## Remove Skill Rate Perks ##
		; -10%
		; This removes -10% skill rate perks for v1.00 users
		PlayerREF.RemovePerk(_sycSkillRateAlchemy090Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration090Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock090Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration090Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction090Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting090Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor090Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion090Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor090Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking090Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman090Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded090Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket090Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration090Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing090Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak090Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft090Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded090Perk)
		; +5%
		PlayerREF.RemovePerk(_sycSkillRateAlchemy105Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration105Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock105Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration105Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction105Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting105Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor105Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion105Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor105Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking105Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman105Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded105Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket105Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration105Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing105Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak105Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft105Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded105Perk)
		; +10%
		PlayerREF.RemovePerk(_sycSkillRateAlchemy110Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration110Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock110Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration110Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction110Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting110Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor110Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion110Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor110Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking110Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman110Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded110Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket110Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration110Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing110Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak110Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft110Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded110Perk)
		; +15%
		PlayerREF.RemovePerk(_sycSkillRateAlchemy115Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration115Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock115Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration115Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction115Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting115Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor115Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion115Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor115Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking115Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman115Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded115Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket115Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration115Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing115Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak115Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft115Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded115Perk)
		; +20%
		PlayerREF.RemovePerk(_sycSkillRateAlchemy120Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration120Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock120Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration120Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction120Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting120Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor120Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion120Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor120Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking120Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman120Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded120Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket120Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration120Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing120Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak120Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft120Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded120Perk)
		; +25%
		PlayerREF.RemovePerk(_sycSkillRateAlchemy125Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration125Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock125Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration125Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction125Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting125Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor125Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion125Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor125Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking125Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman125Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded125Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket125Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration125Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing125Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak125Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft125Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded125Perk)
		; +30%
		PlayerREF.RemovePerk(_sycSkillRateAlchemy130Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration130Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock130Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration130Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction130Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting130Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor130Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion130Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor130Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking130Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman130Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded130Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket130Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration130Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing130Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak130Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft130Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded130Perk)
		; +35%
		PlayerREF.RemovePerk(_sycSkillRateAlchemy135Perk)
		PlayerREF.RemovePerk(_sycSkillRateAlteration135Perk)
		PlayerREF.RemovePerk(_sycSkillRateBlock135Perk)
		PlayerREF.RemovePerk(_sycSkillRateConjuration135Perk)
		PlayerREF.RemovePerk(_sycSkillRateDestruction135Perk)
		PlayerREF.RemovePerk(_sycSkillRateEnchanting135Perk)
		PlayerREF.RemovePerk(_sycSkillRateHeavyArmor135Perk)
		PlayerREF.RemovePerk(_sycSkillRateIllusion135Perk)
		PlayerREF.RemovePerk(_sycSkillRateLightArmor135Perk)
		PlayerREF.RemovePerk(_sycSkillRateLockpicking135Perk)
		PlayerREF.RemovePerk(_sycSkillRateMarksman135Perk)
		PlayerREF.RemovePerk(_sycSkillRateOneHanded135Perk)
		PlayerREF.RemovePerk(_sycSkillRatePickpocket135Perk)
		PlayerREF.RemovePerk(_sycSkillRateRestoration135Perk)
		PlayerREF.RemovePerk(_sycSkillRateSmithing135Perk)
		PlayerREF.RemovePerk(_sycSkillRateSneak135Perk)
		PlayerREF.RemovePerk(_sycSkillRateSpeechcraft135Perk)
		PlayerREF.RemovePerk(_sycSkillRateTwoHanded135Perk)
		
	EndIf
EndFunction


;### Enable Oblivion Carry Weights Function ###
;---------------------------------------------------------------------------------------------------
Function EnableOblivionCarryWeights()
	If bOblivionCarryWeightsApplied == False
		bOblivionCarryWeightsApplied = True
		If bToggleModuleNotificationsOn == True
			Notification("Enabling Oblivion Carry Weights...")
		EndIf
		If PlayerREF.HasSpell(_sycDecreasedCarryWeight100Ability)
		Else
			PlayerREF.AddSpell(_sycDecreasedCarryWeight100Ability, False)
		EndIf
	EndIf
EndFunction


;### Disable Oblivion Carry Weights Function ###
;---------------------------------------------------------------------------------------------------
Function DisableOblivionCarryWeights()
	If bOblivionCarryWeightsApplied == True
		bOblivionCarryWeightsApplied = False
		If bToggleModuleNotificationsOn == True
			Notification("Disabling Oblivion Carry Weights...")
		EndIf
		PlayerREF.RemoveSpell(_sycDecreasedCarryWeight100Ability)
	EndIf
EndFunction


;### Enable Permanent Birthsigns Function ###
;---------------------------------------------------------------------------------------------------
Function EnablePermanentBirthsigns()
	If bPermanentBirthsignsApplied == False
		bPermanentBirthsignsApplied = True
		If bToggleModuleNotificationsOn == True
			Notification("Enabling Permanent Birthsigns...")
		EndIf
	EndIf
EndFunction


;### Disable Permanent Birthsigns Function ###
;---------------------------------------------------------------------------------------------------
Function DisablePermanentBirthsigns()
	If bPermanentBirthsignsApplied == True
		bPermanentBirthsignsApplied = False
		If bToggleModuleNotificationsOn == True
			Notification("Disabling Permanent Birthsigns...")
		EndIf
	EndIf
EndFunction


;---------------------------------------------------------------------------------------------------
;### DEPRECATED FUNCTIONS ###
;---------------------------------------------------------------------------------------------------

;### [DEPRECATED] Assign Race Stats Function ###
;---------------------------------------------------------------------------------------------------
; This function assigns Racial Attributes, Encumbrance, and Skill Rates
; Depreciated after v1.3.0
Function AssignRaceStatsV120()
	ActorBase PlayerREFBase = PlayerREF.GetBaseObject() as ActorBase
	If PlayerREF.GetRace() == ArgonianRace || PlayerREF.GetRace() == ArgonianRaceVampire
		fAlterationSkillRate += 0.05
		fLightArmorSkillRate += 0.05
		fLockpickingSkillRate += 0.10
		fPickpocketSkillRate += 0.05
		fRestorationSkillRate += 0.05
		fSneakSkillRate += 0.05
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		EndIf
	ElseIf PlayerREF.GetRace() == BretonRace || PlayerREF.GetRace() == BretonRaceVampire
		fAlchemySkillRate += 0.05
		fAlterationSkillRate += 0.05
		fConjurationSkillRate += 0.10
		fIllusionSkillRate += 0.05
		fRestorationSkillRate += 0.05
		fSpeechcraftSkillRate += 0.05
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += -10
			fCarryWeightModifier += -50
		EndIf			
	ElseIf PlayerREF.GetRace() == DarkElfRace || PlayerREF.GetRace() == DarkElfRaceVampire
		fAlchemySkillRate += 0.05
		fAlterationSkillRate += 0.05
		fDestructionSkillRate += 0.10
		fIllusionSkillRate += 0.05
		fLightArmorSkillRate += 0.05
		fSneakSkillRate += 0.05
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += 0
		EndIf
	ElseIf PlayerREF.GetRace() == HighElfRace || PlayerREF.GetRace() == HighElfRaceVampire
		fAlterationSkillRate += 0.05
		fConjurationSkillRate += 0.05
		fDestructionSkillRate += 0.05
		fEnchantingSkillRate += 0.05
		fIllusionSkillRate += 0.10
		fRestorationSkillRate += 0.05
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += 0
			fStaminaModifier += 0
			fCarryWeightModifier += -50
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += 0
			fStaminaModifier += -10	
			fCarryWeightModifier += -50
		EndIf			
	ElseIf PlayerREF.GetRace() == ImperialRace || PlayerREF.GetRace() == ImperialRaceVampire
		fBlockSkillRate += 0.05
		fDestructionSkillRate += 0.05
		fEnchantingSkillRate += 0.05
		fHeavyArmorSkillRate += 0.05
		fOneHandedSkillRate += 0.05
		fRestorationSkillRate += 0.10
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += 0
		EndIf			
	ElseIf PlayerREF.GetRace() == KhajiitRace || PlayerREF.GetRace() == KhajiitRaceVampire
		fAlchemySkillRate += 0.05
		fMarksmanSkillRate += 0.05
		fLockpickingSkillRate += 0.05
		fOneHandedSkillRate += 0.05
		fPickpocketSkillRate += 0.05
		fSneakSkillRate += 0.10
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += 0
		Else ; Female
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += 0	
			fCarryWeightModifier += -50
		EndIf
	ElseIf PlayerREF.GetRace() == NordRace || PlayerREF.GetRace() == NordRaceVampire
		fBlockSkillRate += 0.05
		fLightArmorSkillRate += 0.05
		fOneHandedSkillRate += 0.05
		fSmithingSkillRate += 0.05
		fSpeechcraftSkillRate += 0.05
		fTwoHandedSkillRate += 0.10
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 20
			fCarryWeightModifier += 50
		Else ; Female
			fHealthModifier += -20
			fMagickaModifier += -40
			fStaminaModifier += 20
			fCarryWeightModifier += 50
		EndIf			
	ElseIf PlayerREF.GetRace() == OrcRace || PlayerREF.GetRace() == OrcRaceVampire
		fBlockSkillRate += 0.05
		fEnchantingSkillRate += 0.05
		fHeavyArmorSkillRate += 0.10
		fOneHandedSkillRate += 0.05
		fSmithingSkillRate += 0.05
		fTwoHandedSkillRate += 0.05
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 30
			fCarryWeightModifier += 30
		Else ; Female
			fHealthModifier += 0
			fMagickaModifier += -20
			fStaminaModifier += 20
			fCarryWeightModifier += 30
		EndIf			
	ElseIf PlayerREF.GetRace() == RedguardRace || PlayerREF.GetRace() == RedguardRaceVampire
		fAlterationSkillRate += 0.05
		fBlockSkillRate += 0.05
		fDestructionSkillRate += 0.05
		fMarksmanSkillRate += 0.05
		fOneHandedSkillRate += 0.10
		fSmithingSkillRate += 0.05
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 20
			fCarryWeightModifier += 50
		Else ; Female
			fHealthModifier += 0
			fMagickaModifier += -40
			fStaminaModifier += 10
			fCarryWeightModifier += 0
		EndIf
	ElseIf PlayerREF.GetRace() == WoodElfRace || PlayerREF.GetRace() == WoodElfRaceVampire
		fAlchemySkillRate += 0.05
		fLightArmorSkillRate += 0.05
		fMarksmanSkillRate += 0.10
		fLockpickingSkillRate += 0.05
		fPickpocketSkillRate += 0.05
		fSneakSkillRate += 0.05
		If PlayerREFBase.GetSex() == 0	; Male
			fHealthModifier += -20
			fMagickaModifier += -20
			fStaminaModifier += 0
			fCarryWeightModifier += -50
		Else ; Female
			fHealthModifier += -40
			fMagickaModifier += -20
			fStaminaModifier += -10
			fCarryWeightModifier += -50
		EndIf
	Else
		; Custom Race
	Endif
EndFunction


;### [DEPRECATED] Unapply Carry Weight Function ###
;---------------------------------------------------------------------------------------------------
Function UnapplyCarryWeightV120()
	;## Remove Carry Weight Spells ##
	PlayerREF.RemoveSpell(_sycDecreasedCarryWeight50Ability)
	PlayerREF.RemoveSpell(_sycIncreasedCarryWeight30Ability)
	PlayerREF.RemoveSpell(_sycIncreasedCarryWeight50Ability)
EndFunction


;### [DEPRECATED] Disable Dynamic Skill Progression Function ###
;---------------------------------------------------------------------------------------------------
Function DisableDynamicSkillProgressionV120()
	;## Remove Skill Rate Perks ##
	; -10%
	; This removes -10% skill rate perks for v1.00 users
	PlayerREF.RemovePerk(_sycSkillRateAlchemy090Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration090Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock090Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration090Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction090Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting090Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor090Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion090Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor090Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking090Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman090Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded090Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket090Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration090Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing090Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak090Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft090Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded090Perk)
	; +5%
	PlayerREF.RemovePerk(_sycSkillRateAlchemy105Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration105Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock105Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration105Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction105Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting105Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor105Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion105Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor105Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking105Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman105Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded105Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket105Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration105Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing105Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak105Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft105Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded105Perk)
	; +10%
	PlayerREF.RemovePerk(_sycSkillRateAlchemy110Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration110Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock110Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration110Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction110Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting110Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor110Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion110Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor110Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking110Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman110Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded110Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket110Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration110Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing110Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak110Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft110Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded110Perk)
	; +15%
	PlayerREF.RemovePerk(_sycSkillRateAlchemy115Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration115Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock115Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration115Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction115Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting115Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor115Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion115Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor115Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking115Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman115Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded115Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket115Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration115Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing115Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak115Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft115Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded115Perk)
	; +20%
	PlayerREF.RemovePerk(_sycSkillRateAlchemy120Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration120Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock120Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration120Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction120Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting120Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor120Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion120Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor120Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking120Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman120Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded120Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket120Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration120Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing120Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak120Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft120Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded120Perk)
	; +25%
	PlayerREF.RemovePerk(_sycSkillRateAlchemy125Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration125Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock125Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration125Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction125Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting125Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor125Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion125Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor125Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking125Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman125Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded125Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket125Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration125Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing125Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak125Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft125Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded125Perk)
	; +30%
	PlayerREF.RemovePerk(_sycSkillRateAlchemy130Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration130Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock130Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration130Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction130Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting130Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor130Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion130Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor130Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking130Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman130Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded130Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket130Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration130Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing130Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak130Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft130Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded130Perk)
	; +35%
	PlayerREF.RemovePerk(_sycSkillRateAlchemy135Perk)
	PlayerREF.RemovePerk(_sycSkillRateAlteration135Perk)
	PlayerREF.RemovePerk(_sycSkillRateBlock135Perk)
	PlayerREF.RemovePerk(_sycSkillRateConjuration135Perk)
	PlayerREF.RemovePerk(_sycSkillRateDestruction135Perk)
	PlayerREF.RemovePerk(_sycSkillRateEnchanting135Perk)
	PlayerREF.RemovePerk(_sycSkillRateHeavyArmor135Perk)
	PlayerREF.RemovePerk(_sycSkillRateIllusion135Perk)
	PlayerREF.RemovePerk(_sycSkillRateLightArmor135Perk)
	PlayerREF.RemovePerk(_sycSkillRateLockpicking135Perk)
	PlayerREF.RemovePerk(_sycSkillRateMarksman135Perk)
	PlayerREF.RemovePerk(_sycSkillRateOneHanded135Perk)
	PlayerREF.RemovePerk(_sycSkillRatePickpocket135Perk)
	PlayerREF.RemovePerk(_sycSkillRateRestoration135Perk)
	PlayerREF.RemovePerk(_sycSkillRateSmithing135Perk)
	PlayerREF.RemovePerk(_sycSkillRateSneak135Perk)
	PlayerREF.RemovePerk(_sycSkillRateSpeechcraft135Perk)
	PlayerREF.RemovePerk(_sycSkillRateTwoHanded135Perk)
EndFunction

;---------------------------------------------------------------------------------------------------
;### NOTES ###
;---------------------------------------------------------------------------------------------------

; To Do
