﻿using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using fomm.Scripting;

class Script : Fallout3BaseScript
{
    public static bool install = false;
    public static Form InstallForm;
    public static PictureBox BackgroundPicture;
    public static Panel InstallPanel;
    public static Button InstallButton;
    public static Button CancelInstallButton;
    public static Panel OptionsPanel;
    public static Panel UninstallPanel;
    public static CheckBox chbxUninstall;
    public static Label lblUninstall;
    public static Label lblApply;
    public static CheckBox chbxRaceGender;
    public static Label lblRaceGender;
    public static CheckBox chbxDynamicSkill;
    public static Label lblDynamicSkill;
    public static CheckBox chbxCarryWeight;
    public static Label lblCarryWeight;
    public static CheckBox chbxBirthsign;
    public static Label lblBirthsign;

    public static Image GetImageFromFomod(string filename)
    {
        byte[] data = GetFileFromFomod(filename);
        MemoryStream s = new MemoryStream(data);
        Image img = Image.FromStream(s);
        s.Close();
        return img;
    }

    public static void CreateInstallForm()
    {
        InstallForm = CreateCustomForm();

        // customize install form
        InstallForm.FormBorderStyle = FormBorderStyle.None;
        InstallForm.StartPosition = FormStartPosition.CenterScreen;
        InstallForm.Size = new Size(427, 427);

        // place background picture box
        BackgroundPicture = new PictureBox();
        BackgroundPicture.Location = new Point(0, 0);
        BackgroundPicture.Size = new Size(427, 427);

        // load picture file from .fomod and stream into picture box
        BackgroundPicture.Image = GetImageFromFomod("fomod/CCOInstall.png");

        // add BackgroundPicture to list of controls
        InstallForm.Controls.Add(BackgroundPicture);

        // install button
        InstallButton = new Button();
        InstallButton.Text = "Install";
        InstallButton.BackColor = Color.Silver;
        InstallButton.Location = new Point(25, 400);
        InstallButton.Size = new Size(100, 23);

        // cancel button
        CancelInstallButton = new Button();
        CancelInstallButton.Text = "Cancel";
        CancelInstallButton.BackColor = Color.Silver;
        CancelInstallButton.Location = new Point(302, 400);
        CancelInstallButton.Size = new Size(100, 23);

        // options panel
        OptionsPanel = new Panel();
        OptionsPanel.Location = new Point(25, 250);
        OptionsPanel.Size = new Size(250, 130);
        OptionsPanel.BackColor = Color.WhiteSmoke;
        OptionsPanel.BorderStyle = BorderStyle.FixedSingle;
        
        // uninstall panel
        UninstallPanel = new Panel();
        UninstallPanel.Location = new Point(300, 275);
        UninstallPanel.Size = new Size(102, 88);
        UninstallPanel.BackColor = Color.WhiteSmoke;
        UninstallPanel.BorderStyle = BorderStyle.FixedSingle;

        // uninstaller choice
        lblApply = new Label();
        lblApply.Text = "Apply";
        lblApply.Font = new Font("Verdana", 9, FontStyle.Bold);
        lblApply.Location = new Point(330, 285);
        lblApply.AutoSize = true;
        lblUninstall = new Label();
        lblUninstall.Text = "Uninstaller?";
        lblUninstall.Font = new Font("Verdana", 9, FontStyle.Bold);
        lblUninstall.Location = new Point(310, 305);
        lblUninstall.AutoSize = true;
        chbxUninstall = new CheckBox();
        chbxUninstall.Checked = false;
        chbxUninstall.Location = new Point(343, 330);
        chbxUninstall.Size = new Size(20, 20);

        // Diverse Races And Genders
        lblRaceGender = new Label();
        lblRaceGender.Text = "Diverse Races And Genders";
        lblRaceGender.Font = new Font("Verdana", 10, FontStyle.Bold);
        lblRaceGender.Location = new Point(51, 260);
        lblRaceGender.AutoSize = true;
        chbxRaceGender = new CheckBox();
        chbxRaceGender.Checked = true;
        chbxRaceGender.Location = new Point(34, 260);
        chbxRaceGender.Size = new Size(20, 20);

        // Dynamic Skill Progression
        lblDynamicSkill = new Label();
        lblDynamicSkill.Text = "Dynamic Skill Progression";
        lblDynamicSkill.Font = new Font("Verdana", 10, FontStyle.Bold);
        lblDynamicSkill.Location = new Point(51, 290);
        lblDynamicSkill.AutoSize = true;
        chbxDynamicSkill = new CheckBox();
        chbxDynamicSkill.Checked = true;
        chbxDynamicSkill.Location = new Point(34, 290);
        chbxDynamicSkill.Size = new Size(20, 20);

        // Oblivion Carry Weights
        lblCarryWeight = new Label();
        lblCarryWeight.Text = "Oblivion Carry Weights";
        lblCarryWeight.Font = new Font("Verdana", 10, FontStyle.Bold);
        lblCarryWeight.Location = new Point(51, 320);
        lblCarryWeight.AutoSize = true;
        chbxCarryWeight = new CheckBox();
        chbxCarryWeight.Checked = true;
        chbxCarryWeight.Location = new Point(34, 320);
        chbxCarryWeight.Size = new Size(20, 20);

        // Permanent Birthsigns
        lblBirthsign = new Label();
        lblBirthsign.Text = "Permanent Birthsigns";
        lblBirthsign.Font = new Font("Verdana", 10, FontStyle.Bold);
        lblBirthsign.Location = new Point(51, 350);
        lblBirthsign.AutoSize = true;
        chbxBirthsign = new CheckBox();
        chbxBirthsign.Checked = true;
        chbxBirthsign.Location = new Point(34, 350);
        chbxBirthsign.Size = new Size(20, 20);

        // build form
        BackgroundPicture.Controls.Add(InstallButton);
        BackgroundPicture.Controls.Add(CancelInstallButton);
        BackgroundPicture.Controls.Add(chbxUninstall);
        BackgroundPicture.Controls.Add(lblApply);
        BackgroundPicture.Controls.Add(lblUninstall);
        BackgroundPicture.Controls.Add(chbxRaceGender);
        BackgroundPicture.Controls.Add(lblRaceGender);
        BackgroundPicture.Controls.Add(chbxDynamicSkill);
        BackgroundPicture.Controls.Add(lblDynamicSkill);
        BackgroundPicture.Controls.Add(chbxCarryWeight);
        BackgroundPicture.Controls.Add(lblCarryWeight);
        BackgroundPicture.Controls.Add(chbxBirthsign);
        BackgroundPicture.Controls.Add(lblBirthsign);
        BackgroundPicture.Controls.Add(OptionsPanel);
        BackgroundPicture.Controls.Add(UninstallPanel);

        AttachHandlers();
    }
    public static void AttachHandlers()
    {
        //Attach a handler that will fire when the appropriate button is clicked
        InstallButton.Click += delegate(object sender, EventArgs args)
        {
            install = true;
            InstallForm.Close();
        };
        CancelInstallButton.Click += delegate(object sender, EventArgs args)
        {
            install = false;
            InstallForm.Close();
        };
        chbxUninstall.CheckedChanged += delegate(object sender, EventArgs args)
        {
            //Choices don't matter with the uninstaller, so we gray them out
            if (chbxUninstall.Checked) {
                chbxRaceGender.Enabled = false;
                chbxDynamicSkill.Enabled = false;
                chbxCarryWeight.Enabled = false;
                chbxBirthsign.Enabled = false;
            }
            //But choices can be made normally
            else {
                chbxRaceGender.Enabled = true;
                chbxDynamicSkill.Enabled = true;
                chbxCarryWeight.Enabled = true;
                chbxBirthsign.Enabled = true;
            };
        };
    }
    public static void PerformCustomInstall()
    {
        // No matter what choices are made, the main file is always loaded.
        InstallFileFromFomod("Character Creation Overhaul.esp");
        SetPluginActivation("Character Creation Overhaul.esp", true);
        CopyDataFile("Character Creation Overhaul.bsa","Character Creation Overhaul.bsa");

        // We also install all of the documents
        CopyDataFile("Docs/Character Creation Overhaul/CCO Classes.html","Docs/Character Creation Overhaul/CCO Classes.html");
        CopyDataFile("Docs/Character Creation Overhaul/CCO Races.html","Docs/Character Creation Overhaul/CCO Races.html");
        CopyDataFile("Docs/Character Creation Overhaul/readme.txt","Docs/Character Creation Overhaul/readme.txt");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Acrobat.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Acrobat.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Acrobat.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Acrobat.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Agent.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Agent.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Archer.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Archer.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Assassin.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Assassin.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Barbarian.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Barbarian.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Bard.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Bard.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Battlemage.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Battlemage.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Crusader.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Crusader.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Healer.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Healer.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Knight.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Knight.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Mage.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Mage.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Monk.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Monk.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Nightblade.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Nightblade.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Pilgrim.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Pilgrim.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Rogue.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Rogue.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Scout.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Scout.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Sorcerer.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Sorcerer.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Spellsword.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Spellsword.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Thief.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Thief.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Warrior.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Warrior.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/200px-OB-class-Witchhunter.jpg","Docs/Character Creation Overhaul/images/200px-OB-class-Witchhunter.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/CCO-Classes.jpg","Docs/Character Creation Overhaul/images/CCO-Classes.jpg");
        CopyDataFile("Docs/Character Creation Overhaul/images/CCO-Races.jpg","Docs/Character Creation Overhaul/images/CCO-Races.jpg");

        if (chbxUninstall.Checked) {
            // All the optionals are loaded when using the uninstaller
            InstallFileFromFomod("CCO - Diverse Races And Genders.esp");
            SetPluginActivation("CCO - Diverse Races And Genders.esp", true);
            InstallFileFromFomod("CCO - Dynamic Skill Progression.esp");
            SetPluginActivation("CCO - Dynamic Skill Progression.esp", true);
            InstallFileFromFomod("CCO - Oblivion Carry Weights.esp");
            SetPluginActivation("CCO - Oblivion Carry Weights.esp", true);
            InstallFileFromFomod("CCO - Permanent Birthsigns.esp");
            SetPluginActivation("CCO - Permanent Birthsigns.esp", true);

            // Then the uninstaller itself loads up
            CopyDataFile("CCO Uninstaller/CCO - Uninstaller.esp","CCO - Uninstaller.esp");
            SetPluginActivation("CCO - Uninstaller.esp", true);
            CopyDataFile("CCO Uninstaller/CCO - Uninstaller.bsa","CCO - Uninstaller.bsa");
        }
        else {
            // When not using the uninstaller, optionals only load if selected
            if (chbxRaceGender.Checked) {
                InstallFileFromFomod("CCO - Diverse Races And Genders.esp");
                SetPluginActivation("CCO - Diverse Races And Genders.esp", true);
            }
            if (chbxDynamicSkill.Checked) {
                InstallFileFromFomod("CCO - Dynamic Skill Progression.esp");
                SetPluginActivation("CCO - Dynamic Skill Progression.esp", true);
            }
            if (chbxCarryWeight.Checked) {
                InstallFileFromFomod("CCO - Oblivion Carry Weights.esp");
                SetPluginActivation("CCO - Oblivion Carry Weights.esp", true);
            }
            if (chbxBirthsign.Checked) {
                InstallFileFromFomod("CCO - Permanent Birthsigns.esp");
                SetPluginActivation("CCO - Permanent Birthsigns.esp", true);
            }
        }
    }

    public static bool OnActivate()
    {
        CreateInstallForm();
        InstallForm.ShowDialog();
        if(install)
        {
            PerformCustomInstall();
        }
        return install;
    }
}